@@ -139,6 +139,11 @@ LayoutDetails getLayoutDetailsForTransform(QuantType quant_type, int arch)
     {
         return getLayoutDetailsForArch<cutlass::arch::Sm80>(quant_type);
     }
+    else if (arch >= 90 && arch < 110)
+    {
+        FT_LOG_WARNING("Using SM80's layout information for your architecture.");
+        return getLayoutDetailsForArch<cutlass::arch::Sm80>(quant_type);
+    }
     else
     {
         FT_CHECK_WITH_INFO(false, "Unsupported Arch");
