@@ -15,9 +15,10 @@ limitations under the License.
 """
 
 import math
-from typing import Optional
+from typing import Optional, Tuple
 import torch
 
+# mypy: disable-error-code="attr-defined"
 try:
     from . import _kernels
 except ImportError as e:
@@ -31,25 +32,17 @@ except ImportError as e:
         raise e
 
 from .decode import (
-    batch_decode_with_padded_kv_cache_return_lse,
     BatchDecodeWithPagedKVCacheWrapper,
 )
 from .prefill import (
     single_prefill_with_kv_cache_return_lse,
     BatchPrefillWithPagedKVCacheWrapper,
 )
-from .utils import (
-    expand_5d,
-    check_pos_encoding_mode,
-    check_kv_layout,
-    PosEncodingMode,
-    TensorLayout,
-)
 
 
 def merge_state(
     v_a: torch.Tensor, s_a: torch.Tensor, v_b: torch.Tensor, s_b: torch.Tensor
-):
+) -> Tuple[torch.Tensor, torch.Tensor]:
     r"""Merge the attention output ``V`` and the logsumexp value ``S`` from the two
     KV-segments.
     Check :ref:`our tutorial <recursive-attention>` on the mathematical details.
@@ -99,8 +92,12 @@ def merge_state(
 
 
 def merge_state_in_place(
-    v: torch.Tensor, s: torch.Tensor, v_other: torch.Tensor, s_other: torch.Tensor
-):
+    v: torch.Tensor,
+    s: torch.Tensor,
+    v_other: torch.Tensor,
+    s_other: torch.Tensor,
+    mask: Optional[torch.Tensor] = None,
+) -> None:
     r"""Merge the self-attention state ``(v, s)`` with another state
     ``(v_other, s_other)`` in-place.
 
@@ -118,6 +115,11 @@ def merge_state_in_place(
     s_other : torch.Tensor
         The other logsumexp value to be merged, expected to be a float32 tensor,
         shape: ``(seq_len, num_heads)``.
+    mask : Optional[torch.Tensor]
+        The boolean mask tensor for whether to merge the state for a corresponding sequence
+        or not. Useful for CUDA graphs. If not specified (default), will merge states for
+        all sequences.
+        shape: ``[seq_len]``
 
     Example
     -------
@@ -132,10 +134,10 @@ def merge_state_in_place(
     >>> s_other = torch.randn(seq_len, num_heads, dtype=torch.float32).to("cuda:0")
     >>> flashinfer.merge_state_in_place(v, s, v_other, s_other)
     """
-    _kernels.merge_state_in_place(v, s, v_other, s_other)
+    _kernels.merge_state_in_place(v, s, v_other, s_other, mask)
 
 
-def merge_states(v: torch.Tensor, s: torch.Tensor):
+def merge_states(v: torch.Tensor, s: torch.Tensor) -> Tuple[torch.Tensor, torch.Tensor]:
     r"""Merge multiple attention states (v, s).
 
     Parameters
@@ -175,128 +177,238 @@ def merge_states(v: torch.Tensor, s: torch.Tensor):
     return _kernels.merge_states(v, s)
 
 
-def batch_decode_with_shared_prefix_padded_kv_cache(
-    q: torch.Tensor,
-    k_shared: torch.Tensor,
-    v_shared: torch.Tensor,
-    k_unique: torch.Tensor,
-    v_unique: torch.Tensor,
-    kv_layout: str = "NHD",
-    allow_fp16_qk_reduction=False,
-    sm_scale: Optional[float] = None,
-    rope_scale: Optional[float] = None,
-    rope_theta: Optional[float] = None,
-):
-    r"""Decode attention between queries and shared prefix kv-cache for batch of
-    requests.
+class MultiLevelCascadeAttentionWrapper:
+    r"""Attention wrapper for memory efficient multi-level cascade inference, this API assumes all
+    levels KV-Cache are stored in a unified paged table.
 
-    Parameters
-    ----------
-    q : torch.Tensor
-        The query tensor, shape: ``[batch_size, num_qo_heads, head_dim]``.
-    k_shared : torch.Tensor
-        The shared prefix key tensor, shape:
-        ``[shared_prefix_len, num_kv_heads, head_dim]`` if :attr:`kv_layout` is ``NHD``,
-        or ``[num_kv_heads, shared_prefix_len, head_dim]`` if :attr:`kv_layout` is
-        ``HND``.
-    v_shared : torch.Tensor
-        The shared prefix value tensor, shape:
-        ``[shared_prefix_len, num_kv_heads, head_dim]`` if :attr:`kv_layout` is ``NHD``,
-        or ``[num_kv_heads, shared_prefix_len, head_dim]`` if :attr:`kv_layout` is
-        ``HND``.
-    k_unique : torch.Tensor
-        The request-independent suffix key tensor, shape:
-        ``[batch_size, unique_len, num_kv_heads, head_dim]`` if :attr:`kv_layout` is
-        ``NHD``, or ``[batch_size, num_kv_heads, unique_len, head_dim]`` if
-        :attr:`kv_layout` is ``HND``.
-    v_unique : torch.Tensor
-        The request-independent suffix value tensor, shape:
-        ``[batch_size, unique_len, num_kv_heads, head_dim]`` if :attr:`kv_layout` is
-        ``NHD``, or ``[batch_size, num_kv_heads, unique_len, head_dim]`` if
-        :attr:`kv_layout` is ``HND``.
-    kv_layout : str
-        The layout of the kv-cache, could be either "NHD" or "HND".
-    allow_fp16_qk_reduction : bool
-        Whether to use f16 for qk reduction (faster at the cost of slight precision
-        loss).
-    sm_scale : Optional[float]
-        The scale of softmax, if not provided, will be set to ``1 / sqrt(head_dim)``
-    rope_scale : Optional[float]
-        The scale used in RoPE interpolation, if not provided, will be set to ``1.0``.
-    rope_theta : Optional[float]
-        The theta used in RoPE, if not provided, will be set to ``1e4``.
+    Check :ref:`our tutorial<page-layout>` for page table layout, and
+    `Cascade Inference Query/Output Layout <cascade-qo-indptr-layout>` for query/output layout.
 
-    Returns
-    -------
-    V : torch.Tensor
-        The attention output, shape: ``[batch_size, num_heads, head_dim]``
+    The idea of cascade inference is introduced in our `blog post <https://flashinfer.ai/2024/02/02/cascade-inference.html>`_.
 
     Example
     -------
     >>> import torch
     >>> import flashinfer
-    >>> shared_prefix_len = 16384
-    >>> padded_unique_suffix_len = 2048
-    >>> batch_size = 53
-    >>> num_qo_heads = 32
-    >>> num_kv_heads = 32
+    >>> num_layers = 32
+    >>> num_qo_heads = 64
+    >>> num_kv_heads = 8
     >>> head_dim = 128
-    >>> q = torch.randn(batch_size, num_qo_heads, head_dim).half().to("cuda:0")
-    >>> k_shared = torch.randn(shared_prefix_len, num_kv_heads, head_dim).half().to("cuda:0")
-    >>> v_shared = torch.randn(shared_prefix_len, num_kv_heads, head_dim).half().to("cuda:0")
-    >>> k_unique = torch.randn(
-    ...     batch_size,
-    ...     padded_unique_suffix_len,
-    ...     num_kv_heads,
-    ...     head_dim
-    ... ).half().to("cuda:0")
-    >>> v_unique = torch.randn(
-    ...     batch_size,
-    ...     padded_unique_suffix_len,
-    ...     num_kv_heads,
-    ...     head_dim
-    ... ).half().to("cuda:0")
-    >>> o = flashinfer.batch_decode_with_shared_prefix_padded_kv_cache(
-    ...     q, k_shared, v_shared, k_unique, v_unique, kv_layout="NHD",
-    ...     allow_fp16_qk_reduction=True
+    >>> page_size = 16
+    >>> # allocate 128MB workspace buffer
+    >>> workspace_buffer = torch.empty(128 * 1024 * 1024, dtype=torch.uint8, device="cuda:0")
+    >>> wrapper = flashinfer.MultiLevelCascadeAttentionWrapper(
+    ...     2, workspace_buffer, "NHD"
     ... )
-    >>> o.shape
-    torch.Size([53, 32, 128])
+    >>> batch_size = 7
+    >>> shared_kv_num_pages = 512
+    >>> unique_kv_num_pages = 128
+    >>> total_num_pages = shared_kv_num_pages + unique_kv_num_pages
+    >>> shared_kv_page_indices = torch.arange(shared_kv_num_pages).int().to("cuda:0")
+    >>> shared_kv_page_indptr = torch.tensor([0, shared_kv_num_pages], dtype=torch.int32, device="cuda:0")
+    >>> unique_kv_page_indices = torch.arange(shared_kv_num_pages, total_num_pages).int().to("cuda:0")
+    >>> unique_kv_page_indptr = torch.tensor(
+    ...     [0, 17, 29, 44, 48, 66, 100, 128], dtype=torch.int32, device="cuda:0"
+    ... )
+    >>> shared_kv_last_page_len = torch.tensor([page_size], dtype=torch.int32, device="cuda:0")
+    >>> # 1 <= kv_last_page_len <= page_size
+    >>> unique_kv_last_page_len = torch.tensor(
+    ...     [1, 7, 14, 4, 3, 1, 16], dtype=torch.int32, device="cuda:0"
+    ... )
+    >>> kv_cache_at_layer = [
+    ...     torch.randn(
+    ...         total_num_pages, 2, page_size, num_kv_heads, head_dim, dtype=torch.float16, device="cuda:0"
+    ...     ) for _ in range(num_layers)
+    ... ]
+    >>> qo_indptr_arr = [
+    ...     torch.tensor([0, batch_size], dtype=torch.int32, device="cuda:0"),  # top-level for shared KV-Cache
+    ...     torch.arange(batch_size + 1, dtype=torch.int32, device="cuda:0")    # bottom-level for unique KV-Cache
+    ... ]
+    >>> # create auxiliary data structures for batch decode attention
+    >>> wrapper.begin_forward(
+    ...     qo_indptr_arr,
+    ...     [shared_kv_page_indptr, unique_kv_page_indptr],
+    ...     [shared_kv_page_indices, unique_kv_page_indices],
+    ...     [shared_kv_last_page_len, unique_kv_last_page_len],
+    ...     num_qo_heads,
+    ...     num_kv_heads,
+    ...     head_dim,
+    ...     page_size,
+    ... )
+    >>> outputs = []
+    >>> for i in range(num_layers):
+    ...     q = torch.randn(batch_size, num_qo_heads, head_dim).half().to("cuda:0")
+    ...     # compute batch decode attention, reuse auxiliary data structures for all layers
+    ...     o = wrapper.forward(q, kv_cache_at_layer[i])
+    ...     outputs.append(o)
+    ...
+    >>> # clear auxiliary data structures
+    >>> wrapper.end_forward()
+    >>> outputs[0].shape
+    torch.Size([7, 64, 128])
     """
-    check_kv_layout(kv_layout)
-    V_shared, S_shared = single_prefill_with_kv_cache_return_lse(
-        q,
-        k_shared,
-        v_shared,
-        causal=False,
-        pos_encoding_mode="NONE",
-        kv_layout=kv_layout,
-        allow_fp16_qk_reduction=allow_fp16_qk_reduction,
-        sm_scale=sm_scale,
-        rope_scale=rope_scale,
-        rope_theta=rope_theta,
-    )
-    V_unique, S_unique = batch_decode_with_padded_kv_cache_return_lse(
-        q,
-        k_unique,
-        v_unique,
-        kv_layout=kv_layout,
-        pos_encoding_mode="NONE",
-        sm_scale=sm_scale,
-        rope_scale=rope_scale,
-        rope_theta=rope_theta,
-    )
 
-    merge_state_in_place(V_shared, S_shared, V_unique, S_unique)
-    return V_shared
+    def __init__(
+        self, num_levels, float_workspace_buffer: torch.Tensor, kv_layout: str = "NHD"
+    ) -> None:
+        r"""Constructor of :class:`MultiLevelCascadeAttentionWrapper`.
+
+        Parameters
+        ----------
+        num_levels : int
+            The number of levels in the cascade attention.
+        float_workspace_buffer : torch.Tensor
+            The user reserved float workspace buffer used to store intermediate attention results
+            in the split-k algorithm. The recommended size is 128MB, the device of the workspace
+            buffer should be the same as the device of the input tensors.
+        kv_layout : str
+            The layout of the input k/v tensors, could be either ``NHD`` or ``HND``.
+        """
+        self._batch_prefill_wrappers = [
+            BatchPrefillWithPagedKVCacheWrapper(float_workspace_buffer, kv_layout)
+            for _ in range(num_levels)
+        ]
+        self._kv_layout = kv_layout
+
+    def reset_workspace_buffer(
+        self,
+        float_workspace_buffer: torch.Tensor,
+        int_workspace_buffers: list[torch.Tensor],
+    ) -> None:
+        r"""Reset the workspace buffer.
+
+        Parameters
+        ----------
+        float_workspace_buffer : torch.Tensor
+            The new float workspace buffer, the device of the new float workspace buffer should
+            be the same as the device of the input tensors.
+
+        int_workspace_buffer : torch.Tensor
+            The new int workspace buffer, the device of the new int workspace buffer should
+            be the same as the device of the input tensors.
+        """
+        for wrapper, int_workspace_buffer in zip(
+            self._batch_prefill_wrappers, int_workspace_buffers
+        ):
+            wrapper.reset_workspace_buffer(float_workspace_buffer, int_workspace_buffer)
+
+    def begin_forward(
+        self,
+        qo_indptr_arr: list[torch.Tensor],
+        paged_kv_indptr_arr: list[torch.Tensor],
+        paged_kv_indices_arr: list[torch.Tensor],
+        paged_kv_last_page_len: list[torch.Tensor],
+        num_qo_heads: int,
+        num_kv_heads: int,
+        head_dim: int,
+        page_size: int,
+    ):
+        r"""Create auxiliary data structures for multi-level cascade attention for multiple
+        forward calls within the same decode step.
+
+        Parameters
+        ----------
+        qo_indptr_arr : list[torch.Tensor]
+            An array of qo indptr tensors for each level, the array length should be equal to
+            the number of levels. Check
+            `Cascade Inference Query/Output Layout <cascade-qo-indptr-layout>` for query/output layout.
+            The last element of each tensor should be the total number of queries/outputs.
+        paged_kv_indptr_arr : list[torch.Tensor]
+            An array of paged kv-cache indptr tensors for each level, the array length should be
+            equal to the number of levels.
+        paged_kv_indices_arr : list[torch.Tensor]
+            An array of paged kv-cache indices tensors for each level, the array length should be
+            equal to the number of levels.
+        paged_kv_last_page_len : list[torch.Tensor]
+            An array of paged kv-cache last page length tensors for each level, the array length
+            should be equal to the number of levels.
+        num_qo_heads : int
+            The number of query/output heads.
+        num_kv_heads : int
+            The number of key/value heads.
+        head_dim : int
+            The dimension of the heads.
+        page_size : int
+            The page size of the paged kv-cache.
+        """
+        for (
+            wrapper,
+            qo_indptr,
+            paged_kv_indptr,
+            paged_kv_indices,
+            paged_kv_last_page_len,
+        ) in zip(
+            self._batch_prefill_wrappers,
+            qo_indptr_arr,
+            paged_kv_indptr_arr,
+            paged_kv_indices_arr,
+            paged_kv_last_page_len,
+        ):
+            wrapper.begin_forward(
+                qo_indptr,
+                paged_kv_indptr,
+                paged_kv_indices,
+                paged_kv_last_page_len,
+                num_qo_heads,
+                num_kv_heads,
+                head_dim,
+                page_size,
+            )
+
+    def end_forward(self):
+        r"""Clear auxiliary data structures created by :meth:`begin_forward`."""
+        for wrapper in self._batch_prefill_wrappers:
+            wrapper.end_forward()
+
+    def forward(
+        self,
+        q: torch.Tensor,
+        paged_kv_cache: torch.Tensor,
+        **kwargs,
+    ):
+        r"""Compute multi-level cascade attention.
+
+        Parameters
+        ----------
+        q : torch.Tensor
+            The query tensor, shape: ``[batch_size, num_qo_heads, head_dim]``.
+        paged_kv_cache : Union[torch.Tensor, Tuple[torch.Tensor, torch.Tensor]]
+            The paged KV-Cache stored as a tuple of tensors or a single tensor:
+
+            * a tuple ``(k_cache, v_cache)`` of 4-D tensors, each with shape:
+              ``[max_num_pages, page_size, num_kv_heads, head_dim]`` if :attr:`kv_layout` is ``NHD``,
+              and ``[max_num_pages, num_kv_heads, page_size, head_dim]`` if :attr:`kv_layout` is ``HND``.
+
+            * a single 5-D tensor with shape:
+              ``[max_num_pages, 2, page_size, num_kv_heads, head_dim]`` if
+              :attr:`kv_layout` is ``NHD``, and
+              ``[max_num_pages, 2, num_kv_heads, page_size, head_dim]`` if
+              :attr:`kv_layout` is ``HND``. Where ``paged_kv_cache[:, 0]`` is the key-cache and
+              ``paged_kv_cache[:, 1]`` is the value-cache.
+        """
+        out, lse = self._batch_prefill_wrappers[-1].forward_return_lse(
+            q, paged_kv_cache, **kwargs
+        )
+        # NOTE(Zihao): causal mask should be False for all levels except the last level
+        kwargs["causal"] = False
+        for wrapper in self._batch_prefill_wrappers[:-1]:
+            out_i, lse_i = wrapper.forward_return_lse(q, paged_kv_cache, **kwargs)
+            merge_state_in_place(out, lse, out_i, lse_i)
+
+        return out
 
 
 class BatchDecodeWithSharedPrefixPagedKVCacheWrapper:
     r"""Wrapper class for decode attention with shared-prefix paged kv-cache for batch
-    of requests.
+    of requests. The shared-prefix KV-Cache was stored in a standalone tensors, and the
+    unique KV-Cache of each request was stored in a paged KV-Cache data stucture.
 
     Check :ref:`our tutorial<page-layout>` for page table layout.
 
+    It is recommended to use :class:`MultiLevelCascadeAttentionWrapper` instead for general
+    multi-level cascade inference, where the KV-Cache of each level is stored in a unified
+    page table. This API will be deprecated in the future.
+
     Example
     -------
     >>> import torch
@@ -307,8 +419,8 @@ class BatchDecodeWithSharedPrefixPagedKVCacheWrapper:
     >>> head_dim = 128
     >>> max_num_pages = 128
     >>> page_size = 16
-    >>> # allocate 16MB workspace buffer
-    >>> workspace_buffer = torch.empty(16 * 1024 * 1024, dtype=torch.uint8, device="cuda:0")
+    >>> # allocate 128MB workspace buffer
+    >>> workspace_buffer = torch.empty(128 * 1024 * 1024, dtype=torch.uint8, device="cuda:0")
     >>> wrapper = flashinfer.BatchDecodeWithSharedPrefixPagedKVCacheWrapper(
     ...     workspace_buffer, "NHD"
     ... )
@@ -322,7 +434,7 @@ class BatchDecodeWithSharedPrefixPagedKVCacheWrapper:
     >>> unique_kv_last_page_len = torch.tensor(
     ...     [1, 7, 14, 4, 3, 1, 16], dtype=torch.int32, device="cuda:0"
     ... )
-    >>> unique_kv_data_at_layer = [
+    >>> unique_kv_cache_at_layer = [
     ...     torch.randn(
     ...         max_num_pages, 2, page_size, num_kv_heads, head_dim, dtype=torch.float16, device="cuda:0"
     ...     ) for _ in range(num_layers)
@@ -353,9 +465,9 @@ class BatchDecodeWithSharedPrefixPagedKVCacheWrapper:
     ...     q = torch.randn(batch_size, num_qo_heads, head_dim).half().to("cuda:0")
     ...     k_shared = shared_k_data_at_layer[i]
     ...     v_shared = shared_v_data_at_layer[i]
-    ...     unique_kv_data = unique_kv_data_at_layer[i]
+    ...     unique_kv_cache = unique_kv_cache_at_layer[i]
     ...     # compute batch decode attention, reuse auxiliary data structures for all layers
-    ...     o = wrapper.forward(q, k_shared, v_shared, unique_kv_data)
+    ...     o = wrapper.forward(q, k_shared, v_shared, unique_kv_cache)
     ...     outputs.append(o)
     ...
     >>> # clear auxiliary data structures
@@ -371,22 +483,32 @@ class BatchDecodeWithSharedPrefixPagedKVCacheWrapper:
     manages the lifecycle of these data structures.
     """
 
-    def __init__(self, workspace_buffer: torch.Tensor, kv_layout: str = "NHD"):
+    def __init__(
+        self, float_workspace_buffer: torch.Tensor, kv_layout: str = "NHD"
+    ) -> None:
         self._batch_decode_wrapper = BatchDecodeWithPagedKVCacheWrapper(
-            workspace_buffer, kv_layout
+            float_workspace_buffer, kv_layout
         )
         self._kv_layout = kv_layout
 
-    def reset_workspace_buffer(self, new_workspace_buffer: torch.Tensor):
+    def reset_workspace_buffer(
+        self, float_workspace_buffer: torch.Tensor, int_workspace_buffer
+    ) -> None:
         r"""Reset the workspace buffer.
 
         Parameters
         ----------
-        new_workspace_buffer : torch.Tensor
-            The new workspace buffer, the device of the new workspace buffer should
+        float_workspace_buffer : torch.Tensor
+            The new float workspace buffer, the device of the new float workspace buffer should
+            be the same as the device of the input tensors.
+
+        int_workspace_buffer : torch.Tensor
+            The new int workspace buffer, the device of the new int workspace buffer should
             be the same as the device of the input tensors.
         """
-        self._batch_decode_wrapper.reset_workspace_buffer(new_workspace_buffer)
+        self._batch_decode_wrapper.reset_workspace_buffer(
+            float_workspace_buffer, int_workspace_buffer
+        )
 
     def begin_forward(
         self,
@@ -398,7 +520,7 @@ class BatchDecodeWithSharedPrefixPagedKVCacheWrapper:
         head_dim: int,
         page_size: int,
         data_type: str = "float16",
-    ):
+    ) -> None:
         r"""Create auxiliary data structures for shared-prefix batch decode for multiple
         forward calls within the same decode step.
 
@@ -432,6 +554,11 @@ class BatchDecodeWithSharedPrefixPagedKVCacheWrapper:
         The ``num_qo_heads`` must be a multiple of ``num_kv_heads``. If ``num_qo_heads``
         is not equal to ``num_kv_heads``, the function will use
         `grouped query attention <https://arxiv.org/abs/2305.13245>`_.
+
+
+        See Also
+        --------
+        MultiLevelCascadeAttentionWrapper
         """
         self._batch_decode_wrapper.begin_forward(
             unique_kv_indptr,
@@ -445,7 +572,7 @@ class BatchDecodeWithSharedPrefixPagedKVCacheWrapper:
             data_type=data_type,
         )
 
-    def end_forward(self):
+    def end_forward(self) -> None:
         r"""Clear auxiliary data structures created by :meth:`begin_forward`."""
         self._batch_decode_wrapper.end_forward()
 
@@ -454,12 +581,12 @@ class BatchDecodeWithSharedPrefixPagedKVCacheWrapper:
         q: torch.Tensor,
         k_shared: torch.Tensor,
         v_shared: torch.Tensor,
-        unique_kv_data: torch.Tensor,
+        unique_kv_cache: torch.Tensor,
         allow_fp16_qk_reduction=False,
         sm_scale: Optional[float] = None,
         rope_scale: Optional[float] = None,
         rope_theta: Optional[float] = None,
-    ):
+    ) -> torch.Tensor:
         r"""Compute batch decode attention between queries and shared-prefix paged
         kv-cache.
 
@@ -477,13 +604,20 @@ class BatchDecodeWithSharedPrefixPagedKVCacheWrapper:
             ``[shared_prefix_len, num_kv_heads, head_dim]`` if :attr:`kv_layout` is
             ``NHD``, or ``[num_kv_heads, shared_prefix_len, head_dim]`` if
             :attr:`kv_layout` is ``HND``.
-        unique_kv_data : torch.Tensor
-            A 5-D tensor of paged kv-cache data storing the request-independent suffix
-            key and value tensors, shape:
-            ``[max_num_pages, 2, page_size, num_kv_heads, head_dim]`` if
-            :attr:`kv_layout` is ``NHD``, or
-            ``[max_num_pages, 2, page_size, num_kv_heads, head_dim]`` if
-            :attr:`kv_layout` is ``HND``.
+        unique_kv_cache : Union[torch.Tensor, Tuple[torch.Tensor, torch.Tensor]]
+            The request-independent suffix paged KV-Cache stored as a tuple of tensors or a single tensor:
+
+            * a tuple ``(k_cache, v_cache)`` of 4-D tensors, each with shape:
+              ``[max_num_pages, page_size, num_kv_heads, head_dim]`` if :attr:`kv_layout` is ``NHD``,
+              and ``[max_num_pages, num_kv_heads, page_size, head_dim]`` if :attr:`kv_layout` is ``HND``.
+
+            * a single 5-D tensor with shape:
+              ``[max_num_pages, 2, page_size, num_kv_heads, head_dim]`` if
+              :attr:`kv_layout` is ``NHD``, and
+              ``[max_num_pages, 2, num_kv_heads, page_size, head_dim]`` if
+              :attr:`kv_layout` is ``HND``. Where ``paged_kv_cache[:, 0]`` is the key-cache and
+              ``paged_kv_cache[:, 1]`` is the value-cache.
+
         allow_fp16_qk_reduction : bool
             Whether to use f16 for qk reduction (faster at the cost of slight precision
             loss).
@@ -514,7 +648,7 @@ class BatchDecodeWithSharedPrefixPagedKVCacheWrapper:
         )
         V_unique, S_unique = self._batch_decode_wrapper.forward_return_lse(
             q,
-            unique_kv_data,
+            unique_kv_cache,
             pos_encoding_mode="NONE",
             sm_scale=sm_scale,
             rope_scale=rope_scale,
@@ -530,6 +664,10 @@ class BatchPrefillWithSharedPrefixPagedKVCacheWrapper:
 
     Check :ref:`our tutorial<page-layout>` for paged kv-cache layout.
 
+    It is recommended to use :class:`MultiLevelCascadeAttentionWrapper` instead for general
+    multi-level cascade inference, where the KV-Cache of each level is stored in a unified
+    page table. This API will be deprecated in the future.
+
     Example
     -------
     >>> import torch
@@ -540,8 +678,8 @@ class BatchPrefillWithSharedPrefixPagedKVCacheWrapper:
     >>> head_dim = 128
     >>> max_num_pages = 128
     >>> page_size = 16
-    >>> # allocate 16MB workspace buffer
-    >>> workspace_buffer = torch.empty(16 * 1024 * 1024, dtype=torch.uint8, device="cuda:0")
+    >>> # allocate 128MB workspace buffer
+    >>> workspace_buffer = torch.empty(128 * 1024 * 1024, dtype=torch.uint8, device="cuda:0")
     >>> prefill_wrapper = flashinfer.BatchPrefillWithSharedPrefixPagedKVCacheWrapper(
     ...     workspace_buffer, "NHD"
     ... )
@@ -559,7 +697,7 @@ class BatchPrefillWithSharedPrefixPagedKVCacheWrapper:
     >>> paged_kv_last_page_len= torch.tensor(
     ...     [1, 7, 14, 4, 3, 1, 16], dtype=torch.int32, device="cuda:0"
     ... )
-    >>> kv_data_at_layer = [
+    >>> kv_cache_at_layer = [
     ...     torch.randn(
     ...         max_num_pages, 2, page_size, num_kv_heads, head_dim, dtype=torch.float16, device="cuda:0"
     ...     ) for _ in range(num_layers)
@@ -583,16 +721,17 @@ class BatchPrefillWithSharedPrefixPagedKVCacheWrapper:
     ...     num_qo_heads,
     ...     num_kv_heads,
     ...     head_dim,
+    ...     page_size,
     ... )
     >>> outputs = []
     >>> for i in range(num_layers):
     ...     q = torch.randn(nnz_qo, num_qo_heads, head_dim).half().to("cuda:0")
-    ...     kv_data = kv_data_at_layer[i]
+    ...     kv_cache = kv_cache_at_layer[i]
     ...     k_shared = shared_k_data_at_layer[i]
     ...     v_shared = shared_v_data_at_layer[i]
     ...     # compute batch prefill attention, reuse auxiliary data structures
     ...     o = prefill_wrapper.forward(
-    ...         q, k_shared, v_shared, kv_data, causal=True
+    ...         q, k_shared, v_shared, kv_cache, causal=True
     ...     )
     ...     outputs.append(o)
     ...
@@ -609,33 +748,43 @@ class BatchPrefillWithSharedPrefixPagedKVCacheWrapper:
     layers). This wrapper class manages the lifecycle of these data structures.
     """
 
-    def __init__(self, workspace_buffer: torch.Tensor, kv_layout: str = "NHD"):
+    def __init__(
+        self, float_workspace_buffer: torch.Tensor, kv_layout: str = "NHD"
+    ) -> None:
         r"""Constructor of :class:`BatchDecodeWithSharedPrefixPagedKVCacheWrapper`.
 
         Parameters
         ----------
-        workspace_buffer : torch.Tensor
-            The user reserved workspace buffer used to store auxiliary data structures,
-            recommended size is 16MB, the device of the workspace buffer should be the
-            same as the device of the input tensors.
+        float_workspace_buffer : torch.Tensor
+            The user reserved float workspace buffer used to store intermediate attention results
+            in the split-k algorithm. The recommended size is 128MB, the device of the workspace
+            buffer should be the same as the device of the input tensors.
         kv_layout : str
             The layout of the input k/v tensors, could be either ``NHD`` or ``HND``.
         """
         self._batch_prefill_wrapper = BatchPrefillWithPagedKVCacheWrapper(
-            workspace_buffer, kv_layout
+            float_workspace_buffer, kv_layout
         )
         self._kv_layout = kv_layout
 
-    def reset_workspace_buffer(self, new_workspace_buffer: torch.Tensor):
+    def reset_workspace_buffer(
+        self, float_workspace_buffer: torch.Tensor, int_workspace_buffer: torch.Tensor
+    ) -> None:
         r"""Reset the workspace buffer.
 
         Parameters
         ----------
-        new_workspace_buffer : torch.Tensor
-            The new workspace buffer, the device of the new workspace buffer should
+        float_workspace_buffer : torch.Tensor
+            The new float workspace buffer, the device of the new float workspace buffer should
+            be the same as the device of the input tensors.
+
+        int_workspace_buffer : torch.Tensor
+            The new int workspace buffer, the device of the new int workspace buffer should
             be the same as the device of the input tensors.
         """
-        self._batch_prefill_wrapper.reset_workspace_buffer(new_workspace_buffer)
+        self._batch_prefill_wrapper.reset_workspace_buffer(
+            float_workspace_buffer, int_workspace_buffer
+        )
 
     def begin_forward(
         self,
@@ -646,7 +795,8 @@ class BatchPrefillWithSharedPrefixPagedKVCacheWrapper:
         num_qo_heads: int,
         num_kv_heads: int,
         head_dim: int,
-    ):
+        page_size: int,
+    ) -> None:
         r"""Create auxiliary data structures for shared-prefix batch prefill/append
         attention for multiple forward calls within the same prefill/append step.
 
@@ -667,9 +817,11 @@ class BatchPrefillWithSharedPrefixPagedKVCacheWrapper:
             The number of key/value heads.
         head_dim : int
             The dimension of the heads.
+        page_size : int
+            The page size of the paged kv-cache.
 
-        Notes
-        -----
+        Note
+        ----
         The :meth:`begin_forward` method should be called before any :meth:`forward`
         or :meth:`forward_return_lse` calls, auxiliary data structures will be created
         during this call and cached for multiple forward calls.
@@ -687,9 +839,10 @@ class BatchPrefillWithSharedPrefixPagedKVCacheWrapper:
             num_qo_heads,
             num_kv_heads,
             head_dim,
+            page_size,
         )
 
-    def end_forward(self):
+    def end_forward(self) -> None:
         r"""Clear the auxiliary data structures created by :meth:`begin_forward`."""
         self._batch_prefill_wrapper.end_forward()
 
@@ -698,13 +851,13 @@ class BatchPrefillWithSharedPrefixPagedKVCacheWrapper:
         q: torch.Tensor,
         k_shared: torch.Tensor,
         v_shared: torch.Tensor,
-        unique_kv_data: torch.Tensor,
+        unique_kv_cache: torch.Tensor,
         causal: bool = True,
         allow_fp16_qk_reduction: bool = False,
         sm_scale: Optional[float] = None,
         rope_scale: Optional[float] = None,
         rope_theta: Optional[float] = None,
-    ):
+    ) -> torch.Tensor:
         r"""Compute batch prefill/append attention between query and shared-prefix paged
         kv-cache.
 
@@ -722,13 +875,20 @@ class BatchPrefillWithSharedPrefixPagedKVCacheWrapper:
             ``[shared_prefix_len, num_kv_heads, head_dim]`` if :attr:`kv_layout` is
             ``NHD``, or ``[num_kv_heads, shared_prefix_len, head_dim]`` if
             :attr:`kv_layout` is ``HND``.
-        unique_kv_data : torch.Tensor
-            A 5-D tensor of paged kv-cache data storing the request-independent suffix
-            key and value tensors, shape:
-            ``[max_num_pages, 2, page_size, num_kv_heads, head_dim]`` if
-            :attr:`kv_layout` is ``NHD``, or
-            ``[max_num_pages, 2, page_size, num_kv_heads, head_dim]`` if
-            :attr:`kv_layout` is ``HND``.
+        unique_kv_cache : Union[torch.Tensor, Tuple[torch.Tensor, torch.Tensor]]
+            The request-independent suffix paged KV-Cache stored as a tuple of tensors or a single tensor:
+
+            * a tuple ``(k_cache, v_cache)`` of 4-D tensors, each with shape:
+              ``[max_num_pages, page_size, num_kv_heads, head_dim]`` if :attr:`kv_layout` is ``NHD``,
+              and ``[max_num_pages, num_kv_heads, page_size, head_dim]`` if :attr:`kv_layout` is ``HND``.
+
+            * a single 5-D tensor with shape:
+              ``[max_num_pages, 2, page_size, num_kv_heads, head_dim]`` if
+              :attr:`kv_layout` is ``NHD``, and
+              ``[max_num_pages, 2, num_kv_heads, page_size, head_dim]`` if
+              :attr:`kv_layout` is ``HND``. Where ``paged_kv_cache[:, 0]`` is the key-cache and
+              ``paged_kv_cache[:, 1]`` is the value-cache.
+
         causal : bool
             Whether to apply causal mask on the attention matrix.
         allow_fp16_qk_reduction : bool
@@ -746,6 +906,10 @@ class BatchPrefillWithSharedPrefixPagedKVCacheWrapper:
         -------
         V : torch.Tensor
             The attention output, shape: ``[qo_indptr[-1], num_heads, head_dim]``.
+
+        See Also
+        --------
+        MultiLevelCascadeAttentionWrapper
         """
         V_shared, S_shared = single_prefill_with_kv_cache_return_lse(
             q,
@@ -761,7 +925,7 @@ class BatchPrefillWithSharedPrefixPagedKVCacheWrapper:
         )
         V_unique, S_unique = self._batch_prefill_wrapper.forward_return_lse(
             q,
-            unique_kv_data,
+            unique_kv_cache,
             causal=causal,
             pos_encoding_mode="NONE",
             allow_fp16_qk_reduction=allow_fp16_qk_reduction,
