@@ -14,9 +14,21 @@ See the License for the specific language governing permissions and
 limitations under the License.
 """
 
-kv_layout_literal = {
-    0: "QKVLayout::kNHD",
-    1: "QKVLayout::kHND",
+mask_mode_literal = {
+    0: "MaskMode::kNone",
+    1: "MaskMode::kCausal",
+    2: "MaskMode::kCustom",
+}
+
+logits_hook_literal = {
+    0: "LogitsPostHook::kNone",
+    1: "LogitsPostHook::kSoftCap",
+}
+
+warp_layout_literal = {
+    0: "WarpLayout::k4x1x2",
+    1: "WarpLayout::k4x1x1",
+    2: "WarpLayout::k1x4x1",
 }
 
 pos_encoding_mode_literal = {
