@@ -26,14 +26,33 @@
 
 #include <tvm/relax/expr.h>
 #include <tvm/relax/struct_info.h>
-#include <tvm/te/schedule.h>
 #include <tvm/te/tensor.h>
 
-#include <string>
-
 namespace tvm {
 namespace relax {
 
+enum OpPatternKind {
+  // Elementwise operation
+  kElemWise = 0,
+  // Broadcasting operator, can always map output axis to the input in order.
+  // for example :code:`out[i, ax1, j, ax2] = input[i, j]`.
+  // Note that the axis need to be in order so transpose is not a bcast operator.
+  kBroadcast = 1,
+  // Injective operator, can always injectively map output axis to a single input axis.
+  // All injective operator can still be safely fused to injective and reduction.
+  kInjective = 2,
+  // Communicative reduction operator.
+  kCommReduce = 3,
+  // Complex operation, can still fuse elemwise operations into its output.
+  // but cannot chain another complex op
+  kOutEWiseFusable = 4,
+  // The pattern for tuple nodes. Can fuse into subsequent injective ops,
+  // but treated specially
+  kTuple = 7,
+  // Opaque operation, cannot fuse anything.
+  kOpaque = 8
+};
+
 /*!
  * \brief Infer output struct info given the call
  *
@@ -82,7 +101,7 @@ using FNormalize = runtime::TypedPackedFunc<Expr(const BlockBuilder& bb, Call ca
  *    this delay between generating an ill-formed `relax::Call` and
  *    identifying the ill-formed call may complicate debugging.  If
  *    the validation logic is very fast to check, and doing so would
- *    not introduce a signficant overhead, consider validating as part
+ *    not introduce a significant overhead, consider validating as part
  *    of `FNormalize`, which is applied by the block builder for each
  *    `relax::Call`.
  *
