@@ -77,11 +77,12 @@ struct TypeIndex {
     /*! \brief runtime::RPCObjectRef */
     kRuntimeRPCObjectRef = 9,
     // static assignments that may subject to change.
-    kRuntimeClosure,
-    kRuntimeADT,
-    kStaticIndexEnd,
-    /*! \brief Type index is allocated during runtime. */
-    kDynamic = kStaticIndexEnd
+    kStaticIndexEnd = 10,
+    /*!
+     * \brief Type index is allocated during runtime, keeping it as
+     * constant for now to ensure compatibility across versions
+     */
+    kDynamic = 12
   };
 };  // namespace TypeIndex
 
@@ -339,8 +340,8 @@ class TVM_DLL Object {
  * \tparam ObjectType The object type
  * \return The corresponding RefType
  */
-template <typename RelayRefType, typename ObjectType>
-inline RelayRefType GetRef(const ObjectType* ptr);
+template <typename ObjectRefType, typename ObjectType>
+inline ObjectRefType GetRef(const ObjectType* ptr);
 
 /*!
  * \brief Downcast a base reference type to a more specific type.
@@ -505,8 +506,8 @@ class ObjectPtr {
   friend class TVMRetValue;
   friend class TVMArgValue;
   friend class TVMMovableArgValue_;
-  template <typename RelayRefType, typename ObjType>
-  friend RelayRefType GetRef(const ObjType* ptr);
+  template <typename ObjectRefType, typename ObjType>
+  friend ObjectRefType GetRef(const ObjType* ptr);
   template <typename BaseType, typename ObjType>
   friend ObjectPtr<BaseType> GetObjectPtr(ObjType* ptr);
 };
