@@ -513,7 +513,7 @@ TVM_DLL PrimExpr pow(PrimExpr x, PrimExpr y, Span span = Span());
  * \param x The input data
  * \param span The location of this operation in the source.
  *
- * \return The aboslute value of input data x
+ * \return The absolute value of input data x
  */
 TVM_DLL PrimExpr abs(PrimExpr x, Span span = Span());
 /*!
@@ -940,7 +940,7 @@ inline PrimExpr MakeConstScalar(DataType t, ValueType value, Span span = Span())
       return LargeUIntImm(t, static_cast<int64_t>(low), static_cast<int64_t>(high), span);
     }
   }
-  if (t.is_float() || t.is_bfloat16() || t.is_float8())
+  if (t.is_float() || t.is_bfloat16() || t.is_float8() || t.is_float4())
     return FloatImm(t, static_cast<double>(value), span);
   // For now, we store const scalar values of custom datatypes within doubles; later, during the
   // datatypes lowering pass, we will lower the value to its true representation in the format
