@@ -15,7 +15,7 @@
 # specific language governing permissions and limitations
 # under the License.
 # pylint: disable=invalid-name, dangerous-default-value, arguments-differ
-"""Driver for partitioning and building a Relay module for CUTLASS offload."""
+"""Driver for partitioning and building a Relax module for CUTLASS offload."""
 import itertools
 import logging
 import multiprocessing
@@ -25,7 +25,7 @@ from functools import reduce
 from typing import Optional, Sequence
 
 import tvm
-from tvm import relax, relay, runtime
+from tvm import relax, runtime
 from tvm._ffi.registry import register_func
 from tvm.contrib.nvcc import get_cuda_version
 from tvm.topi.utils import get_const_tuple
@@ -39,7 +39,7 @@ logger = logging.getLogger("cutlass")
 
 def has_cutlass():
     """Returns true if the CUTLASS custom codegen is available"""
-    return tvm.get_global_func("relay.ext.cutlass.create_c_source_module", True) is not None
+    return tvm.get_global_func("relax.ext.cutlass", True) is not None
 
 
 def _get_cutlass_path():
@@ -89,35 +89,6 @@ def _get_cutlass_compile_options(sm, threads, use_fast_math=False):
     return kwargs
 
 
-class OpAnnotator(tvm.relay.ExprVisitor):
-    """Annotates partitioned functions with shape and dtype information."""
-
-    def __init__(self):
-        super().__init__()
-        self.signature = {}
-
-    def visit_call(self, call):
-        op = call.op
-        if isinstance(op, relay.Function) and "Composite" in op.attrs:
-            self.signature["op_type"] = op.attrs["Composite"]
-            for i, arg in enumerate(op.params):
-                self.signature[f"arg{i}_shape"] = arg.checked_type.shape
-                self.signature[f"arg{i}_dtype"] = arg.checked_type.dtype
-            self.signature["ret_shape"] = op.ret_type.shape
-            self.signature["ret_dtype"] = op.ret_type.dtype
-            self.visit(op.body)
-
-        elif isinstance(op, tvm.ir.Op) and op.name in [
-            "nn.conv2d",
-            "nn.conv2d_transpose",
-            "nn.conv2d_backward_weight",
-        ]:
-            self.op_attrs = call.attrs
-
-        for arg in call.args:
-            self.visit(arg)
-
-
 def select_gemm_kernel(
     cutlass_profiler,
     op_type,
@@ -327,7 +298,7 @@ def tune_cutlass_kernels(
     Parameters
     ----------
     mod : IRModule
-        The Relay module with cutlass partitions.
+        The IRModule with cutlass partitions.
 
     sm : int
         An integer specifying the compute capability. For example, 75 for Turing and
@@ -389,148 +360,6 @@ def tune_cutlass_kernels(
     return mod, num_cutlass_partition
 
 
-def tune_cutlass_function(
-    func,
-    use_3xtf32,
-    split_k_slices,
-    profile_all_alignments,
-    find_first_valid,
-    use_multiprocessing,
-    gemm_profiler,
-    conv2d_profiler,
-):
-    """Given a function intended to be offloaded to CUTLASS,  profile each workload to select which
-    kernels to emit.
-
-    Parameters
-    ----------
-    func : IRModule
-        The Relay Function to tune for.
-
-    use_3xtf32 : bool
-        Wheter or not use slower but very accurate (compared to tf32) 3xtf32 mode for
-        fp32 inputs on tensorcore.
-
-    split_k_slices : list of int
-        Split factor candidates for split-K GEMM. If split-K > 1, the GEMM K-loop is computed in
-        parallel accross split-K blocks, and a seperate global reduction kernel is launched to
-        accumulate partial reductions. The profiler will pick the best split-k factor from the
-        given candidate list. Note that the larger split-K factor requires a larger workspace.
-        Currently, parallel split-k has been tested only for wgrad. For GEMM and other conv2d
-        kinds, split_k_slices is ignored.
-
-    profile_all_alignments : bool
-        When True, profile all kernal variants with smaller alignments than the largest possible.
-
-    find_first_valid : bool
-        Whether or not profile all candidate kernels, or stop profiling after
-        the first applicable kernel is found.
-
-    use_multiprocessing : bool
-        Whether or not compile profiler executables for different kernels in parallel.
-
-    gemm_profiler : CutlassGemmProfiler
-        Profiler for dense operators. May cache results between tuned functions.
-
-    conv2d_profiler : CutlassConv2DProfiler
-        Profiler for conv2d operators. May cach results between tuned functions.
-
-    Returns
-    -------
-    annot_func : Function
-        The input function with attributes capturing the best CUTLASS kernel found by tuning.
-    """
-    annotator = OpAnnotator()
-    annotator.visit(func)
-    out_shape = annotator.signature["ret_shape"]
-    out_dtype = annotator.signature["ret_dtype"]
-    op_type = annotator.signature["op_type"]
-
-    new_attrs = {"op_type": op_type}
-    new_attrs.update(annotator.signature)
-    new_attrs.update(func.attrs)
-    arg0_shape = new_attrs["arg0_shape"]
-    arg1_shape = new_attrs["arg1_shape"]
-    arg0_dtype = new_attrs["arg0_dtype"]
-    arg1_dtype = new_attrs["arg1_dtype"]
-
-    if "conv2d" in op_type:
-        new_attrs["padding"] = annotator.op_attrs.padding
-        new_attrs["strides"] = annotator.op_attrs.strides
-        new_attrs["dilation"] = annotator.op_attrs.dilation
-
-        if "conv2d_transpose" in op_type:
-            d_shape = out_shape
-            w_shape = arg1_shape
-        elif "conv2d_backward_weight" in op_type:
-            d_shape = arg1_shape
-            w_shape = out_shape
-        else:
-            d_shape = arg0_shape
-            w_shape = arg1_shape
-
-        new_attrs.update(
-            handle_conv2d(
-                conv2d_profiler,
-                op_type,
-                d_shape,
-                w_shape,
-                annotator.op_attrs.padding,
-                annotator.op_attrs.strides,
-                annotator.op_attrs.dilation,
-                out_dtype,
-                arg0_dtype,
-                arg1_dtype,
-                use_3xtf32,
-                split_k_slices,
-                profile_all_alignments,
-                find_first_valid,
-                use_multiprocessing,
-            )
-        )
-    elif "batch_matmul" in op_type:
-        new_attrs.update(
-            handle_batch_matmul(
-                gemm_profiler,
-                op_type,
-                arg0_shape,
-                arg1_shape,
-                out_dtype,
-                arg0_dtype,
-                arg1_dtype,
-                use_3xtf32,
-                find_first_valid,
-                use_multiprocessing,
-            )
-        )
-    elif "dense" in op_type:
-        new_attrs.update(
-            handle_dense(
-                gemm_profiler,
-                op_type,
-                arg0_shape,
-                arg1_shape,
-                out_dtype,
-                arg0_dtype,
-                arg1_dtype,
-                use_3xtf32,
-                find_first_valid,
-                use_multiprocessing,
-            )
-        )
-    else:
-        raise ValueError(f"{op_type} unsupported composite")
-
-    new_attrs = tvm.ir.make_node("DictAttrs", **new_attrs)
-    return relay.Function(
-        func.params,
-        func.body,
-        ret_type=func.ret_type,
-        type_params=func.type_params,
-        attrs=new_attrs,
-    )
-
-
 def _get_call_node(expr: relax.Expr, op_name: str) -> Optional[relax.Call]:
     node = None
 
@@ -1047,52 +876,6 @@ def compile_cutlass_module(c_source_module, options):
     return tvm.runtime.load_static_library(lib_path, function_names)
 
 
-@register_func("relay.ext.cutlass.compile_for_cutlass")
-def compile_for_cutlass(mod, cutlass_target):
-    """Given an IRModule with at least one Compiler='cutlass' Relay function, return a
-    LibraryModule with all such functions compiled into their PackedFunc-compatible form.
-     - First runs CUTLASS tuning to decide on the best kernels, which itself requires the
-       repeated compilation and execution of CUDA code using nvcc. The results of this
-       is captured as annotation on each relevant function. Kernel performance is cached
-       overall all functions.
-     - Then generates a single CSourceModule containing C code implementing all the
-       Compiler='cutlass' Relay functions, accounting for the tuning done above.
-     - Then compiles that CSourceModule with the appropriate nvcc arguments to yield
-       a static .o library. An export_library step will be required on the final runtime
-       module to link that library into the overall .so library.
-     See CompileForCutlass in src/relay/backend/contrib/cutlass/codegen.cc for where this
-     helper function is used to implement the RelayToTIR pass hook for CUTLASS."""
-
-    # Recover options from the current 'cutlass' Target
-    assert cutlass_target.kind.name == "cutlass"
-    tuning_config = {
-        key: cutlass_target.attrs.get(key)
-        for key in [
-            "sm",
-            "use_3xtf32",
-            "split_k_slices",
-            "profile_all_alignments",
-            "find_first_valid",
-            "use_multiprocessing",
-        ]
-    }
-    compile_config = {
-        key: cutlass_target.attrs.get(key) for key in ["sm", "threads", "use_fast_math"]
-    }
-    tmp_dir = cutlass_target.attrs.get("tmp_dir")
-    compile_config["tmp_dir"] = tmp_dir
-
-    # Tune
-    logger.info("Tuning for CUTLASS")
-    mod, _ = tune_cutlass_kernels(mod, tmp_dir=tmp_dir, **tuning_config)
-
-    # Compile
-    logger.info("Creating CSource module for CUTLASS")
-    create_c_source_module = tvm._ffi.get_global_func("relay.ext.cutlass.create_c_source_module")
-    c_module = create_c_source_module(mod)
-    return compile_cutlass_module(c_module, compile_config)
-
-
 def finalize_modules(lib, lib_path="compile.so", tmp_dir="./tmp"):
     """Returns lib with any C source, LLVM and static library modules complied and linked in ready
     for use by the graph or AOT executors. This method is not specific to CUTLASS, however it does
@@ -1102,7 +885,7 @@ def finalize_modules(lib, lib_path="compile.so", tmp_dir="./tmp"):
     Parameters
     ----------
     lib : runtime.Module
-        The output from relay.build.
+        The output from build.
 
     lib_path : string
         The path to a shared library which will be generated as the result of the build process.
@@ -1119,38 +902,3 @@ def finalize_modules(lib, lib_path="compile.so", tmp_dir="./tmp"):
     lib_path = os.path.join(tmp_dir, lib_path)
     lib.export_library(lib_path, workspace_dir=tmp_dir, cc="nvcc")
     return runtime.load_module(lib_path)
-
-
-def finalize_modules_vm(vm_exec, lib_path="compile.so", vmcode_path="vmcode.ro", tmp_dir="./tmp"):
-    """Returns vm_exec with any C source, LLVM and static library modules compiled and linked in
-    ready for use by the VM executor. This method is not specific to CUTLASS, however it does
-    assume nvcc will be used for final compilation and linking. It is provided here for
-    convenience.
-
-    Parameters
-    ----------
-    vm_exec : vm.Executable
-        The output from relay.vm.compile containing compiled host code and kernels.
-
-    lib_path : string
-        The path to a shared library which will be generated as the result of the build process.
-
-    vmcode_path : string
-        The path where the VM bytecode will be serialized to as a side-effect.
-
-    tmp_dir : string
-        A temporary directory where intermediate compiled artifacts will be stored.
-
-    Returns
-    -------
-    updated_vm_exec : vm.Executable
-        The updated VM executable with all compilation and linking completed.
-    """
-    code, lib = vm_exec.save()
-    lib_path = os.path.join(tmp_dir, lib_path)
-    vmcode_path = os.path.join(tmp_dir, vmcode_path)
-    lib.export_library(lib_path, workspace_dir=tmp_dir, cc="nvcc")
-    with open(vmcode_path, "wb") as fo:
-        fo.write(code)
-    lib = tvm.runtime.load_module(lib_path)
-    return tvm.runtime.vm.Executable.load_exec(code, lib)
