@@ -129,7 +129,9 @@ def _worker_func(hexagon_launcher, evaluator_config, alloc_repeat, artifact_path
 
 
 def get_hexagon_local_builder(
-    pass_context: tvm.transform.PassContext = None, max_workers: Optional[int] = None
+    pass_context: tvm.transform.PassContext = None,
+    max_workers: Optional[int] = None,
+    timeout_sec: float = 30.0,
 ):
     """Return Hexagon-compatible Builder for meta schedule."""
 
@@ -146,10 +148,13 @@ def get_hexagon_local_builder(
 
     if pass_context is not None:
         return LocalBuilder(
-            f_build=default_build_with_context, f_export=export_func, max_workers=max_workers
+            f_build=default_build_with_context,
+            f_export=export_func,
+            max_workers=max_workers,
+            timeout_sec=timeout_sec,
         )
     else:
-        return LocalBuilder(f_export=export_func, max_workers=max_workers)
+        return LocalBuilder(f_export=export_func, max_workers=max_workers, timeout_sec=timeout_sec)
 
 
 def get_hexagon_rpc_runner(
