@@ -14,7 +14,7 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-""" TVM Attribute module, which is mainly used for defining attributes of operators."""
+"""TVM Attribute module, which is mainly used for defining attributes of operators."""
 import tvm._ffi
 
 from tvm.runtime import Object
@@ -24,7 +24,7 @@ from . import _ffi_api
 
 @tvm._ffi.register_object
 class Attrs(Object):
-    """Attribute node, which is mainly use for defining attributes of relay operators.
+    """Attribute node, which is mainly use for defining attributes of operators.
 
     Used by function registered in python side, such as compute, schedule and alter_layout.
     Attrs is passed as the first argument to these functions.
