@@ -21,7 +21,7 @@ from typing import Union, Dict
 from enum import IntEnum
 import tvm.runtime
 from tvm.runtime.object import Object
-from .expr import RelayExpr
+from .expr import RelaxExpr
 from .attrs import DictAttrs
 from . import _ffi_api
 
@@ -34,7 +34,7 @@ class CallingConv(IntEnum):
     DEVICE_KERNEL_LAUNCH = 2
 
 
-class BaseFunc(RelayExpr):
+class BaseFunc(RelaxExpr):
     """Base class of all functions."""
 
     @property
