@@ -28,6 +28,7 @@ from tvm._ffi import register_object, register_func
 from tvm.runtime import Object
 from tvm.target import Target
 from tvm.tir import PrimFunc, Schedule
+from tvm.script import tir as T
 
 from . import _ffi_api
 from .logging import Logger, get_logger, get_logging_func
@@ -47,7 +48,7 @@ def _normalize_mod(mod: Union[PrimFunc, IRModule]) -> IRModule:
     if isinstance(mod, PrimFunc):
         if not (mod.attrs and "global_symbol" in mod.attrs):
             mod = mod.with_attr("global_symbol", "main")
-        mod = mod.with_attr("tir.noalias", True)
+        mod = mod.with_attr("tir.noalias", T.bool(True))
         mod = IRModule({"main": mod})
     if not isinstance(mod, IRModule):
         raise TypeError(f"Expected `mod` to be PrimFunc or IRModule, but gets: {mod}")
