@@ -79,10 +79,10 @@ class SortScanDispatcher(BackendDispatcher):
             kwargs = {}
             with tgt:
                 if can_use_thrust(tgt, "tvm.contrib.thrust.sort"):
-                    te_func = topi.cuda.sort_thrust
+                    te_func = topi.gpu.sort_thrust
                     kwargs["workspace"] = self.allocate_workspace(call)
                 elif self.is_gpu_target(tgt):
-                    te_func = topi.cuda.sort
+                    te_func = topi.gpu.sort
             return self.builder_.call_te(
                 te_func, call.args[0], call.attrs.axis, not call.attrs.descending, **kwargs
             )
@@ -92,10 +92,10 @@ class SortScanDispatcher(BackendDispatcher):
             kwargs = {}
             with tgt:
                 if can_use_thrust(tgt, "tvm.contrib.thrust.sort"):
-                    te_func = topi.cuda.argsort_thrust
+                    te_func = topi.gpu.argsort_thrust
                     kwargs["workspace"] = self.allocate_workspace(call)
                 elif self.is_gpu_target(tgt):
-                    te_func = topi.cuda.argsort
+                    te_func = topi.gpu.argsort
             return self.builder_.call_te(
                 te_func,
                 call.args[0],
@@ -109,10 +109,10 @@ class SortScanDispatcher(BackendDispatcher):
             te_func = topi.topk
             kwargs = {}
             if can_use_thrust(tgt, "tvm.contrib.thrust.sort"):
-                te_func = topi.cuda.topk_thrust
+                te_func = topi.gpu.topk_thrust
                 kwargs["workspace"] = self.allocate_workspace(call)
             elif self.is_gpu_target(tgt):
-                te_func = topi.cuda.topk
+                te_func = topi.gpu.topk
             tir_call = self.builder_.call_te(
                 te_func,
                 call.args[0],
@@ -141,7 +141,7 @@ class SortScanDispatcher(BackendDispatcher):
                 and call.op.name == "relax.cumsum"
                 and call.attrs.exclusive == 0
             ):
-                from tvm.relax.backend_tir import (  # pylint: disable=import-outside-toplevel
+                from tvm.relax.backend.gpu_generic import (  # pylint: disable=import-outside-toplevel
                     gpu_2d_continuous_cumsum,
                 )
 
@@ -176,11 +176,11 @@ class SortScanDispatcher(BackendDispatcher):
 
             with tgt:
                 if call.op.name == "relax.cumsum":
-                    te_func = topi.cuda.cumsum if self.is_gpu_target(tgt) else topi.cumsum
+                    te_func = topi.gpu.cumsum if self.is_gpu_target(tgt) else topi.cumsum
                     if can_use_thrust(tgt, "tvm.contrib.thrust.sum_scan"):
                         kwargs["workspace"] = self.allocate_workspace(call)
                 elif call.op.name == "relax.cumprod":
-                    te_func = topi.cuda.cumprod if self.is_gpu_target(tgt) else topi.cumprod
+                    te_func = topi.gpu.cumprod if self.is_gpu_target(tgt) else topi.cumprod
                 else:
                     raise ValueError(f"Unsupported op: {call.op.name}")
                 tir_call = self.builder_.call_te(
