@@ -27,7 +27,7 @@ try:
 except ImportError:
     ml_dtypes = None
 import tvm._ffi
-from tvm._ffi.base import _FFI_MODE, _LIB, c_array, check_call, string_types
+from tvm._ffi.base import _LIB, c_array, check_call, string_types
 from tvm._ffi.runtime_ctypes import (
     DataType,
     DataTypeCode,
@@ -36,30 +36,15 @@ from tvm._ffi.runtime_ctypes import (
     TVMArrayHandle,
     tvm_shape_index_t,
 )
+from tvm._ffi._cy3.core import (
+    NDArrayBase,
+    _from_dlpack,
+    _make_array,
+    _set_class_ndarray,
+)
 
 from . import _ffi_api
 
-try:
-    # pylint: disable=wrong-import-position
-    if _FFI_MODE == "ctypes":
-        raise ImportError()
-    from tvm._ffi._cy3.core import (
-        NDArrayBase,
-        _from_dlpack,
-        _make_array,
-        _set_class_ndarray,
-    )
-except (RuntimeError, ImportError) as error:
-    # pylint: disable=wrong-import-position
-    if _FFI_MODE == "cython":
-        raise error
-    from tvm._ffi._ctypes.ndarray import (
-        NDArrayBase,
-        _from_dlpack,
-        _make_array,
-        _set_class_ndarray,
-    )
-
 
 @tvm._ffi.register_object("runtime.NDArray")
 class NDArray(NDArrayBase):
@@ -197,6 +182,15 @@ class NDArray(NDArrayBase):
             source_array = np.ascontiguousarray(
                 source_array, dtype="uint16" if dtype == "bfloat16" else dtype
             )
+        if self.dtype.startswith("float4_e2m1fn") and self.dtype != "float4_e2m1fn":
+            # float4_e2m1fn in numpy is not packed.
+            # So we need to pack the input data when converting to vectorized float4_e2m1fn type.
+            data_bits = source_array.view(dtype="uint8")
+            if data_bits.size % 2:
+                data_bits = np.pad(data_bits, (0, 1), mode="constant", constant_values=0)
+            data_bits = data_bits.reshape(-1, 2)
+            packed = ((data_bits[:, 0] & 0x0F) << 4) | (data_bits[:, 1] & 0x0F)
+            source_array = packed.astype(np.int8)
         assert source_array.flags["C_CONTIGUOUS"]
         data = source_array.ctypes.data_as(ctypes.c_void_p)
         nbytes = ctypes.c_size_t(source_array.size * source_array.dtype.itemsize)
@@ -239,35 +233,54 @@ class NDArray(NDArrayBase):
         if dtype == "int4":
             dtype = "int8"
         if dtype == "bfloat16":
-            dtype = "uint16"
-        if dtype == "e4m3_float8":
+            if ml_dtypes is not None:
+                dtype = ml_dtypes.bfloat16
+            else:
+                raise RuntimeError(
+                    "ml_dtypes is not installed, cannot convert bfloat16 array to numpy."
+                )
+        if dtype == "float8_e4m3fn":
             if ml_dtypes is not None:
                 dtype = ml_dtypes.float8_e4m3fn
             else:
                 raise RuntimeError(
-                    "ml_dtypes is not installed, cannot convert e4m3_float8 array to numpy."
+                    "ml_dtypes is not installed, cannot convert float8_e4m3fn array to numpy."
                 )
-        if dtype == "e5m2_float8":
+        if dtype == "float8_e5m2":
             if ml_dtypes is not None:
                 dtype = ml_dtypes.float8_e5m2
             else:
                 raise RuntimeError(
-                    "ml_dtypes is not installed, cannot convert e5m2_float8 array to numpy."
+                    "ml_dtypes is not installed, cannot convert float8_e5m2 array to numpy."
+                )
+        if dtype == "float4_e2m1fn":
+            if ml_dtypes is not None:
+                dtype = ml_dtypes.float4_e2m1fn
+            else:
+                raise RuntimeError(
+                    "ml_dtypes is not installed, cannot convert float4_e2m1fn array to numpy."
                 )
         np_arr = np.empty(shape, dtype=dtype)
         assert np_arr.flags["C_CONTIGUOUS"]
         data = np_arr.ctypes.data_as(ctypes.c_void_p)
-        nbytes = ctypes.c_size_t(np_arr.size * np_arr.dtype.itemsize)
+        if old_dtype.startswith("float4_e2m1fn") and old_dtype != "float4_e2m1fn":
+            nbytes = ctypes.c_size_t(np_arr.size * np_arr.dtype.itemsize // 2)
+        else:
+            nbytes = ctypes.c_size_t(np_arr.size * np_arr.dtype.itemsize)
         check_call(_LIB.TVMArrayCopyToBytes(self.handle, data, nbytes))
-        if old_dtype == "int4":
+        if old_dtype == "int4" or (
+            old_dtype.startswith("float4_e2m1fn") and old_dtype != "float4_e2m1fn"
+        ):
             length = np_arr.size
+            np_arr = np_arr.view("int8")
             np_arr_ret = np.empty((length,), dtype="int8")
             np_arr = np_arr.reshape((length,))
             old_index = np.bitwise_and(np_arr, 0x0F)
             even_index = np.bitwise_and(np_arr >> 4, 0x0F)
             np_arr_ret[1::2] = old_index[0 : length // 2]
             np_arr_ret[0::2] = even_index[0 : length // 2]
-            return np_arr_ret.reshape(shape)
+            return np_arr_ret.reshape(shape).view(dtype)
+
         return np_arr
 
     def copyto(self, target, mem_scope=None):
