@@ -18,28 +18,17 @@
 """Runtime Object API"""
 import ctypes
 
-from tvm._ffi.base import _FFI_MODE, _LIB, _RUNTIME_ONLY, c_str, check_call
+from tvm._ffi.base import _LIB, _RUNTIME_ONLY, c_str, check_call
 from tvm._ffi.runtime_ctypes import ObjectRValueRef
+from tvm._ffi._cy3.core import (
+    ObjectBase,
+    PyNativeObject,
+    _set_class_object,
+    _set_class_object_generic,
+)
 
 from . import _ffi_api, _ffi_node_api
 
-try:
-    # pylint: disable=wrong-import-position,unused-import
-    if _FFI_MODE == "ctypes":
-        raise ImportError()
-    from tvm._ffi._cy3.core import (
-        ObjectBase,
-        PyNativeObject,
-        _set_class_object,
-        _set_class_object_generic,
-    )
-except (RuntimeError, ImportError) as error:
-    # pylint: disable=wrong-import-position,unused-import
-    if _FFI_MODE == "cython":
-        raise error
-    from tvm._ffi._ctypes.object import ObjectBase, PyNativeObject
-    from tvm._ffi._ctypes.packed_func import _set_class_object, _set_class_object_generic
-
 
 def _new_object(cls):
     """Helper function for pickle"""
