@@ -16,7 +16,7 @@
 # under the License.
 """Package tvm.script.ir_builder.ir.ir"""
 
-from typing import Dict, List
+from typing import Dict, List, Optional
 
 from tvm.ir import BaseFunc, GlobalVar, GlobalInfo, VDevice, DummyGlobalInfo
 from tvm.runtime import Object as tvm_Object
@@ -77,14 +77,66 @@ def def_function(func_name: str, func: BaseFunc) -> None:
     return _ffi_api.DefFunction(func_name, func)  # type: ignore[attr-defined] # pylint: disable=no-member
 
 
-def module_attrs(attrs: Dict[str, tvm_Object]) -> None:
+def module_attrs(attrs: Dict[str, tvm_Object], allow_overwrite=False) -> None:
     """Specify the attrs of the ir_module frame.
     Parameters
     ----------
     attrs: Dict[str, Object]
         The module attrs.
+    allow_overwrite: bool
+        Whether allow overwrite the existing attrs.
     """
-    return _ffi_api.ModuleAttrs(attrs)  # type: ignore[attr-defined] # pylint: disable=no-member
+    return _ffi_api.ModuleAttrs(attrs, allow_overwrite)  # type: ignore[attr-defined] # pylint: disable=no-member
+
+
+def current_ir_module() -> IRModuleFrame:
+    """Get the current ir_module frame.
+    Returns
+    -------
+    frame: IRModuleFrame
+        The current frame.
+    """
+    return _ffi_api.CurrentIRModule()  # type: ignore[attr-defined] # pylint: disable=no-member
+
+
+def module_get_attrs() -> Dict[str, tvm_Object]:
+    """Get the attrs of the ir_module frame.
+    Returns
+    -------
+    attrs: Dict[str, Object]
+        The module attrs.
+    """
+    return _ffi_api.ModuleGetAttrs()  # type: ignore[attr-defined] # pylint: disable=no-member
+
+
+def module_get_attr(attr_key: str) -> Optional[tvm_Object]:
+    """Get the specified attr of the ir_module frame.
+    Parameters
+    ----------
+    attr_key: str
+        The key of the attr to be retrieved.
+    Returns
+    -------
+    attr: Optional[Object]
+        The specified module attr or None if not found.
+    """
+    return _ffi_api.ModuleGetAttr(attr_key)  # type: ignore[attr-defined] # pylint: disable=no-member
+
+
+def module_set_attr(
+    attr_key: str, attr_value: Optional[tvm_Object], allow_overwrite: bool = False
+) -> None:
+    """Set the specified attr of the ir_module frame.
+    Parameters
+    ----------
+    attr_key: str
+        The key of the attr to be set.
+    attr_value: Optional[Object]
+        The value of the attr to be set.
+    allow_overwrite: bool
+        Whether allow overwrite the existing attr.
+    """
+    return _ffi_api.ModuleSetAttr(attr_key, attr_value, allow_overwrite)  # type: ignore[attr-defined] # pylint: disable=no-member
 
 
 def module_global_infos(global_infos: Dict[str, List[GlobalInfo]]) -> None:
