@@ -139,8 +139,11 @@ def macro(*args, hygienic: bool = True) -> Callable:
     def _decorator(func: Callable) -> TIRMacro:
         source, closure_vars = scan_macro(func, utils.inspect_function_capture(func))
         obj = TIRMacro(source, closure_vars, func, hygienic)
-        obj.__name__ = func.__name__
-        return obj
+
+        def wrapper(*args, **kwargs):
+            return obj(*args, **kwargs)
+
+        return wrapper
 
     if len(args) == 0:
         return _decorator
