@@ -28,21 +28,11 @@ from tvm.tir import div, indexdiv, indexmod, truncdiv, truncmod, floordiv, floor
 from tvm.tir import comm_reducer, min, max, sum
 from tvm.tir import add, subtract, multiply
 
-from .schedule import (
-    Schedule,
-    Stage,
-    create_schedule,
-    SpecializedCondition,
-    AXIS_SEPARATOR,
-)
 from .tensor import TensorSlice, Tensor
-from .tensor_intrin import decl_tensor_intrin
 from .tag import tag_scope
 from .operation import placeholder, compute, scan, extern, var, size_var, const
-from .operation import thread_axis, reduce_axis
+from .operation import thread_axis, reduce_axis, AXIS_SEPARATOR
 from .operation import create_prim_func
 from .operation import extern_primfunc
 
-from .tensor import PlaceholderOp, ComputeOp, TensorComputeOp, ScanOp, ExternOp, HybridOp
-from .autodiff import gradient
-from . import hybrid
+from .tensor import PlaceholderOp, ComputeOp, ScanOp, ExternOp
