@@ -1308,15 +1308,3 @@ class Let(PrimExprWithOp):
         self, var: Var, value: PrimExpr, body: PrimExpr, span: Optional[Span] = None
     ) -> None:
         self.__init_handle_by_constructor__(_ffi_api.Let, var, value, body, span)  # type: ignore
-
-
-@tvm._ffi.register_object("tir.Any")
-class Any(PrimExprWithOp):
-    """Any node.
-
-    span : Optional[Span]
-        The location of this expression in the source code.
-    """
-
-    def __init__(self, span: Optional[Span] = None) -> None:
-        self.__init_handle_by_constructor__(_ffi_api.Any, span)  # type: ignore
