@@ -16,8 +16,4 @@
 # under the License.
 # pylint: disable=unused-import
 """Intrinsics for tensorization."""
-from .x86 import *
-from .arm_cpu import *
-from .dot_product_common import *
-from .rocm import *
-from .cuda import *
+from . import arm_cpu, cuda, rocm, x86, hexagon
