@@ -18,8 +18,8 @@
 """Depthwise convolution operators"""
 from __future__ import absolute_import as _abs
 from collections import namedtuple
-import tvm
 import numpy as np
+import tvm
 from tvm import te
 
 from .dilate import dilate
@@ -65,30 +65,23 @@ def _get_workload(data, kernel, stride, padding, dilation, out_dtype, data_layou
     elif data_layout == "NCHWc":
         _, in_channel_chunk, height, width, in_channel_block = get_const_tuple(data.shape)
         in_channel = in_channel_chunk * in_channel_block
-        (
-            filter_channel_chunk,
-            cm_chunk,
-            kh,
-            kw,
-            cm_block,
-            filter_channel_block,
-        ) = get_const_tuple(kernel.shape)
+        (filter_channel_chunk, cm_chunk, kh, kw, cm_block, filter_channel_block) = get_const_tuple(
+            kernel.shape
+        )
         filter_channel = filter_channel_chunk * filter_channel_block
         channel_multiplier = cm_chunk * cm_block
 
-        assert (
-            in_channel_block == filter_channel_block
-        ), "Incorrect dimensions, data has block size {}, but filter has block size {}".format(
-            in_channel_block, filter_channel_block
+        assert in_channel_block == filter_channel_block, (
+            f"Incorrect dimensions, data has block size {in_channel_block}, but filter has "
+            f"block size {filter_channel_block}"
         )
 
     else:
-        raise ValueError("Data layout {} not supported".format(data_layout))
+        raise ValueError(f"Data layout {data_layout} not supported")
 
-    assert (
-        in_channel == filter_channel
-    ), "Incorrect dimensions, data has {} channels but filter expects {} channels".format(
-        in_channel, filter_channel
+    assert in_channel == filter_channel, (
+        f"Incorrect dimensions, data has {in_channel} channels but filter expects "
+        f"{filter_channel} channels"
     )
 
     out_channel = filter_channel * channel_multiplier
@@ -101,10 +94,7 @@ def _get_workload(data, kernel, stride, padding, dilation, out_dtype, data_layou
         HSTR, WSTR = stride, stride
     assert (data.dtype == kernel.dtype) or (
         data.dtype == "uint8" and kernel.dtype == "int8"
-    ), "Do not support inputs with different data types now. ' \
-        '{} vs. {}".format(
-        data.dtype, kernel.dtype
-    )
+    ), f"Do not support inputs with different data types now. {data.dtype} vs. {kernel.dtype}"
     dilated_kernel_h = (kh - 1) * dilation_h + 1
     dilated_kernel_w = (kw - 1) * dilation_w + 1
     pt, pl, pb, pr = get_pad_tuple(padding, (dilated_kernel_h, dilated_kernel_w))
@@ -467,23 +457,3 @@ def depthwise_conv2d_NCHWc(
         5-D with shape [batch, out_channel_chunk, out_height, out_width, out_channel_block]
     """
     raise ValueError("missing register for topi.nn.depthwise_conv2d_NCHWc")
-
-
-@tvm.target.generic_func
-def depthwise_conv2d_infer_layout(workload, cfg):
-    """Infer input/output shapes and layouts from a workload and cfg.
-
-    Parameters
-    ----------
-    workload : tuple
-        conv2d workload
-
-    cfg : tuple
-        tvm.autotvm config
-
-    Returns
-    -------
-    Output : [tuple of tuple and str, tuple of tuple and str]
-        Input shapes and layouts, and output shapes and layouts
-    """
-    raise ValueError("missing register for topi.nn.depthwise_conv2d_infer_layout")
