@@ -20,7 +20,6 @@ from __future__ import absolute_import as _abs
 
 import tvm
 from tvm import te, topi
-from tvm.te import hybrid
 
 from . import cpp, tag
 from .utils import const_vector, make_idx, within_index
@@ -474,28 +473,6 @@ def take(a, indices, axis=None, batch_dims=0, mode="clip"):
     return cpp.take(a, indices, int(batch_dims), int(axis), mode)
 
 
-@tvm.target.generic_func
-def take_legalize(attrs, inputs, types):
-    """Legalizes dyn.topk op.
-
-    Parameters
-    ----------
-    attrs : tvm.ir.Attrs
-        Attributes of current op
-    inputs : list of tvm.relay.Expr
-        The args of the Relay expr to be legalized
-    types : list of types
-        List of input and output types
-    Returns
-    -------
-    result : tvm.relay.Expr
-        The legalized expr
-    """
-    if tvm.relay.ty.is_dynamic(types[0]):
-        return tvm.relay.take(tvm.relay.annotation.stop_fusion(inputs[0]), inputs[1], **attrs)
-    return None
-
-
 def gather(data, axis, indices):
     """Gather values along given axis from given indices.
 
@@ -816,12 +793,12 @@ def one_hot(indices, on_value, off_value, depth, axis, dtype):
     axis : int
         Axis to fill.
 
-    dtype : relay.DataType
+    dtype : str
         Data type of the output tensor.
 
     Returns
     -------
-    ret : relay.Expr
+    ret : tvm.te.Tensor
         The one-hot tensor.
 
     Examples
@@ -830,7 +807,7 @@ def one_hot(indices, on_value, off_value, depth, axis, dtype):
 
         indices = [0, 1, 2]
 
-        relay.one_hot(indices, 3) =
+        topi.one_hot(indices, 3) =
             [[1, 0, 0],
              [0, 1, 0],
              [0, 0, 1]]
@@ -846,15 +823,15 @@ def unravel_index(indices, shape):
 
     Parameters
     ----------
-    indices : relay.Expr
+    indices : tvm.te.Tensor
         An integer array containing indices.
 
-    shape : relay.Expr
+    shape : tvm.te.Tensor
         The shape of the array.
 
     Returns
     -------
-    result : relay.Expr
+    result : tvm.te.Tensor
         The tuple of coordinate arrays.
     """
 
@@ -897,10 +874,10 @@ def matrix_set_diag(data, diagonal, k=0, align="RIGHT_LEFT"):
 
     Parameters
     ----------
-    data : relay.Expr
+    data : tvm.te.Tensor
         Input Tensor.
 
-    diagonal : relay.Expr
+    diagonal : tvm.te.Tensor
         Values to be filled in the diagonal.
 
     k : int or tuple of int, optional
@@ -920,7 +897,7 @@ def matrix_set_diag(data, diagonal, k=0, align="RIGHT_LEFT"):
 
     Returns
     -------
-    result : relay.Expr
+    result : tvm.te.Tensor
         New tensor with given diagonal values.
 
     Examples
@@ -982,41 +959,12 @@ def adv_index(data, indices):
     return cpp.adv_index(data, indices)
 
 
-@hybrid.script
-def invert_permutation(data):
-    """Computes the inverse permutation of data.
-
-    Parameters
-    ----------
-    data : tvm.te.Tensor
-        Input data
-
-    Returns
-    -------
-    result : tvm.te.Tensor
-        Output tensor
-
-    Examples
-    --------
-    .. code-block:: python
-
-        data = [3, 4, 0, 2, 1]
-        topi.invert_permutation(data) = [2, 4, 3, 0, 1]
-    """
-    result = output_tensor(data.shape, data.dtype)
-    nums = data.shape[0]
-    for ind in range(nums):
-        r_ind = data[ind]
-        result[r_ind] = ind
-    return result
-
-
 def sliding_window(data, axis, window_shape, strides):
     """Slide a window over the data tensor.
 
     Parameters
     ----------
-    data : relay.Expr
+    data : tvm.te.Tensor
         The input data to the operator.
 
     axis : int
@@ -1035,7 +983,7 @@ def sliding_window(data, axis, window_shape, strides):
 
     Returns
     -------
-    result : relay.Expr
+    result : tvm.te.Tensor
         The resulting tensor.
     """
     return cpp.sliding_window(data, axis, window_shape, strides)
@@ -1063,7 +1011,7 @@ def trilu(data, k, upper):
 
     Returns
     -------
-    ret : relay.Expr
+    ret : tvm.te.Tensor
         The new tensor with appropriate diagonals set to zero.
 
     Examples
@@ -1074,7 +1022,7 @@ def trilu(data, k, upper):
              [3, 4, 5],
              [6, 7, 8]]
 
-        relay.trilu(x, True, 0) =
+        topi.trilu(x, True, 0) =
             [[0, 1, 2],
              [0, 4, 5],
              [0, 0, 8]]
