@@ -23,7 +23,7 @@ from numbers import Integral
 import numpy as np
 import tvm
 from tvm import te
-from tvm.tir import Any, SizeVar, bijective_layout, layout
+from tvm.tir import SizeVar, bijective_layout, layout
 
 from . import cpp, tag
 
@@ -187,7 +187,7 @@ def get_const_tuple(in_tuple):
     ret = []
     ana = None
     for elem in in_tuple:
-        if isinstance(elem, (tvm.tir.Var, tvm.tir.expr.Any)):
+        if isinstance(elem, tvm.tir.Var):
             ret.append(elem)
         elif not isinstance(elem, (tvm.tir.IntImm, int)):
             ana = tvm.arith.Analyzer() if ana is None else ana
@@ -525,4 +525,4 @@ def is_target(names):
 
 def is_dynamic_shape(shape):
     """Checks if any part of a shape is dynamic"""
-    return any([isinstance(x, (Any, SizeVar)) for x in shape])
+    return any([isinstance(x, SizeVar) for x in shape])
