@@ -35,13 +35,14 @@ namespace contrib {
 namespace msc {
 
 MSCTensor::MSCTensor(const String& name, const DataType& dtype, const String& layout,
-                     const Array<Integer>& shape, const String& alias) {
+                     const Array<Integer>& shape, const String& alias, const Array<String>& prims) {
   ObjectPtr<MSCTensorNode> n = make_object<MSCTensorNode>();
   n->name = std::move(name);
   n->alias = std::move(alias);
   n->dtype = std::move(dtype);
   n->shape = std::move(shape);
   n->layout = tvm::tir::Layout(layout);
+  n->prims = prims;
   data_ = std::move(n);
 }
 
@@ -68,6 +69,9 @@ const JsonMSCTensor MSCTensorNode::ToJson() const {
   for (const auto& s : shape) {
     j_tensor.shape.push_back(s->value);
   }
+  for (const auto& p : prims) {
+    j_tensor.prims.push_back(p);
+  }
   return j_tensor;
 }
 
@@ -81,6 +85,9 @@ void MSCTensorNode::FromJson(const JsonMSCTensor& j_tensor) {
   for (const auto& s : j_tensor.shape) {
     shape.push_back(s);
   }
+  for (const auto& p : j_tensor.prims) {
+    prims.push_back(p);
+  }
 }
 
 void MSCTensorNode::FromJson(const std::string& json_str) {
@@ -103,6 +110,17 @@ const Integer MSCTensorNode::DimAt(const String& axis) const {
   return DimAt(index);
 }
 
+const String MSCTensorNode::PrimAt(int index) const {
+  if (prims.size() == 0) {
+    return "";
+  }
+  return prims[CommonUtils::GetIndex(index, Ndim())];
+}
+
+const String MSCTensorNode::PrimAt(const String& axis) const {
+  return PrimAt(layout.IndexOf(tvm::tir::LayoutAxis::Get(axis)));
+}
+
 int32_t MSCTensorNode::LayoutOf(const String& axis) const {
   return layout.IndexOf(tvm::tir::LayoutAxis::Get(axis));
 }
@@ -498,6 +516,76 @@ const std::pair<MSCJoint, size_t> MSCJointNode::ProducerAndIdxOf(const MSCTensor
   return ProducerAndIdxOf(input->name);
 }
 
+MSCPrim::MSCPrim(int index, const String& name, const String& optype,
+                 const Array<BaseJoint>& parents, const Map<String, String>& attrs) {
+  ObjectPtr<MSCPrimNode> n = make_object<MSCPrimNode>();
+  n->index = index;
+  n->name = std::move(name);
+  n->optype = std::move(optype);
+  n->attrs = std::move(attrs);
+  for (const auto& p : parents) {
+    n->parents.push_back(p);
+  }
+  data_ = std::move(n);
+}
+
+MSCPrim::MSCPrim(const JsonMSCPrim& j_prim, const Map<String, BaseJoint>& prims) {
+  ObjectPtr<MSCPrimNode> n = make_object<MSCPrimNode>();
+  n->FromJson(j_prim, prims);
+  data_ = std::move(n);
+}
+
+MSCPrim::MSCPrim(const std::string& json_str, const Map<String, BaseJoint>& prims) {
+  ObjectPtr<MSCPrimNode> n = make_object<MSCPrimNode>();
+  n->FromJson(json_str, prims);
+  data_ = std::move(n);
+}
+
+const JsonMSCPrim MSCPrimNode::ToJson() const {
+  JsonMSCPrim j_prim;
+  j_prim.index = index;
+  j_prim.name = name;
+  j_prim.optype = optype;
+  for (const auto& pair : attrs) {
+    j_prim.attrs[pair.first] = pair.second;
+  }
+  for (const auto& p : parents) {
+    j_prim.parents.push_back(Downcast<BaseJoint>(p)->name);
+  }
+  return j_prim;
+}
+
+void MSCPrimNode::FromJson(const JsonMSCPrim& j_prim, const Map<String, BaseJoint>& prims) {
+  index = j_prim.index;
+  name = j_prim.name;
+  optype = j_prim.optype;
+  for (const auto& pair : j_prim.attrs) {
+    attrs.Set(pair.first, pair.second);
+  }
+  for (const auto& p_name : j_prim.parents) {
+    ICHECK(prims.count(p_name)) << "Can not find parent " << p_name;
+    parents.push_back(prims[p_name]);
+  }
+}
+
+void MSCPrimNode::FromJson(const std::string& json_str, const Map<String, BaseJoint>& prims) {
+  std::istringstream is(json_str);
+  dmlc::JSONReader reader(&is);
+  JsonMSCPrim j_prim;
+  reader.Read(&j_prim);
+  FromJson(j_prim, prims);
+}
+
+const MSCPrim MSCPrimNode::ParentAt(int index) const {
+  size_t v_index = CommonUtils::GetIndex(index, parents.size());
+  return Downcast<MSCPrim>(parents[v_index]);
+}
+
+const MSCPrim MSCPrimNode::ChildAt(int index) const {
+  size_t v_index = CommonUtils::GetIndex(index, children.size());
+  return Downcast<MSCPrim>(children[v_index]);
+}
+
 WeightJoint::WeightJoint(int index, const String& name, const String& shared_ref,
                          const String& weight_type, const MSCTensor& weight,
                          const Array<BaseJoint> parents, const Map<String, String>& attrs,
@@ -587,7 +675,8 @@ const bool BaseGraphNode::HasNode(const String& name) const {
 }
 
 MSCGraph::MSCGraph(const String& name, const Array<MSCJoint>& nodes,
-                   const Array<String>& input_names, const Array<String>& output_names) {
+                   const Array<String>& input_names, const Array<String>& output_names,
+                   const Array<MSCPrim>& prims) {
   ObjectPtr<MSCGraphNode> n = make_object<MSCGraphNode>();
   n->name = std::move(name);
   for (const auto& node : nodes) {
@@ -596,6 +685,10 @@ MSCGraph::MSCGraph(const String& name, const Array<MSCJoint>& nodes,
   }
   n->input_names = std::move(input_names);
   n->output_names = std::move(output_names);
+  for (const auto& prim : prims) {
+    n->prim_names.push_back(prim->name);
+    n->prims.Set(prim->name, prim);
+  }
   n->AnalysisGraph();
   data_ = std::move(n);
 }
@@ -625,6 +718,10 @@ const JsonMSCGraph MSCGraphNode::ToJson() const {
     const auto& node = FindNode(n);
     j_graph.nodes.push_back(node->ToJson());
   }
+  for (const auto& n : prim_names) {
+    const auto& prim = FindPrim(n);
+    j_graph.prims.push_back(prim->ToJson());
+  }
   return j_graph;
 }
 
@@ -646,6 +743,16 @@ void MSCGraphNode::FromJson(const JsonMSCGraph& j_graph) {
     node_names.push_back(node->name);
     nodes.Set(node->name, node);
   }
+  Map<String, BaseJoint> loaded_prims;
+  for (const auto& n : j_graph.prims) {
+    const auto& prim = MSCPrim(n, loaded_prims);
+    loaded_prims.Set(prim->name, prim);
+    for (const auto& p : prim->parents) {
+      Downcast<BaseJoint>(p)->AddChild(prim);
+    }
+    prim_names.push_back(prim->name);
+    prims.Set(prim->name, prim);
+  }
   AnalysisGraph();
 }
 
@@ -697,6 +804,11 @@ const MSCJoint MSCGraphNode::FindNode(const String& name) const {
   return Downcast<MSCJoint>(nodes[name]);
 }
 
+const MSCPrim MSCGraphNode::FindPrim(const String& name) const {
+  ICHECK(prims.count(name)) << "Can not find prim " << name;
+  return prims[name];
+}
+
 const MSCTensor MSCGraphNode::InputAt(int index) const {
   size_t v_index = CommonUtils::GetIndex(index, input_names.size());
   return FindTensor(input_names[v_index]);
@@ -1004,9 +1116,8 @@ void WeightGraphNode::Build(const MSCGraph& graph, const Map<String, Array<Strin
         const auto& tensor = node->OutputAt(0);
         Map<String, String> attrs;
         attrs.Set("producer_type", node->optype);
-        if (node->optype == "reshape" && node->InputAt(0)->LayoutOf("C") >= 0 &&
-            node->OutputAt(0)->LayoutOf("C") >= 0 &&
-            node->InputAt(0)->DimAt("C")->value == node->OutputAt(0)->DimAt("C")->value) {
+        if (node->optype == "reshape") {
+          // TODO(archermmt): check non-passby reshape
           attrs.Set("weight_strategy", "passby");
         } else {
           attrs.Set("weight_strategy", relation_wtypes[node->optype]);
@@ -1155,7 +1266,11 @@ MSCGraph PruneWeights(const MSCGraph& graph, const Map<String, MSCTensor>& prune
       Downcast<BaseJoint>(p)->AddChild(new_node);
     }
   }
-  return MSCGraph(graph->name, nodes, graph->input_names, graph->output_names);
+  Array<MSCPrim> prims;
+  for (const auto& name : graph->prim_names) {
+    prims.push_back(graph->FindPrim(name));
+  }
+  return MSCGraph(graph->name, nodes, graph->input_names, graph->output_names, prims);
 }
 
 TVM_STATIC_IR_FUNCTOR(ReprPrinter, vtable)
@@ -1168,7 +1283,9 @@ TVM_STATIC_IR_FUNCTOR(ReprPrinter, vtable)
       }
       p->stream << "<";
       for (size_t i = 0; i < tensor->Ndim(); i++) {
-        p->stream << tensor->shape[i]->value << (i == tensor->Ndim() - 1 ? "|" : ",");
+        const auto& prim = tensor->PrimAt(i);
+        p->stream << (prim.size() > 0 ? prim : StringUtils::ToString(tensor->shape[i]))
+                  << (i == tensor->Ndim() - 1 ? "|" : ",");
       }
       p->stream << tensor->dtype;
       if (tensor->layout.defined()) {
@@ -1177,8 +1294,8 @@ TVM_STATIC_IR_FUNCTOR(ReprPrinter, vtable)
       p->stream << ">";
     });
 
-#define MSC_NODE_BASE_HEAD(Stream, Joint)                                                \
-  Stream << "ID_" << Joint->index << " " << Joint->name;                                 \
+#define MSC_NODE_BASE_HEAD(Stream, Joint, Type)                                          \
+  Stream << Type << "_" << Joint->index << " " << Joint->name;                           \
   if (Joint->shared_ref.size() > 0) {                                                    \
     Stream << "(M: " << Joint->shared_ref << ")";                                        \
   }                                                                                      \
@@ -1200,7 +1317,7 @@ TVM_STATIC_IR_FUNCTOR(ReprPrinter, vtable)
     .set_dispatch<MSCJointNode>([](const ObjectRef& node, ReprPrinter* p) {
       auto* joint = static_cast<const MSCJointNode*>(node.get());
       p->PrintIndent();
-      MSC_NODE_BASE_HEAD(p->stream, joint);
+      MSC_NODE_BASE_HEAD(p->stream, joint, "N");
       if (joint->inputs.size() > 0) {
         p->stream << "  IN: ";
         for (size_t i = 0; i < joint->inputs.size(); i++) {
@@ -1234,11 +1351,26 @@ TVM_STATIC_IR_FUNCTOR(ReprPrinter, vtable)
       }
     });
 
+TVM_STATIC_IR_FUNCTOR(ReprPrinter, vtable)
+    .set_dispatch<MSCPrimNode>([](const ObjectRef& node, ReprPrinter* p) {
+      auto* prim = static_cast<const MSCPrimNode*>(node.get());
+      p->PrintIndent();
+      MSC_NODE_BASE_HEAD(p->stream, prim, "P");
+      p->stream << "  OPTYPE: " << prim->optype;
+      if (prim->attrs.size() > 0) {
+        p->stream << "\n  ATTRS: ";
+        for (const auto& pair : prim->attrs) {
+          p->stream << pair.first << "=" << pair.second << " ";
+        }
+      }
+      p->stream << "\n";
+    });
+
 TVM_STATIC_IR_FUNCTOR(ReprPrinter, vtable)
     .set_dispatch<WeightJointNode>([](const ObjectRef& node, ReprPrinter* p) {
       auto* joint = static_cast<const WeightJointNode*>(node.get());
       p->PrintIndent();
-      MSC_NODE_BASE_HEAD(p->stream, joint);
+      MSC_NODE_BASE_HEAD(p->stream, joint, "W");
       if (joint->friends.size() > 0) {
         p->stream << "  FRIENDS: ";
         for (size_t i = 0; i < joint->friends.size(); i++) {
@@ -1279,6 +1411,9 @@ TVM_STATIC_IR_FUNCTOR(ReprPrinter, vtable)
       for (size_t i = 0; i < graph->output_names.size(); i++) {
         p->stream << graph->output_names[i] << (i == graph->output_names.size() - 1 ? ">\n" : ",");
       }
+      for (const auto& n : graph->prim_names) {
+        p->stream << graph->FindPrim(n) << "\n";
+      }
       for (const auto& n : graph->node_names) {
         p->stream << graph->FindNode(n) << "\n";
       }
@@ -1288,6 +1423,8 @@ TVM_REGISTER_NODE_TYPE(MSCTensorNode);
 
 TVM_REGISTER_NODE_TYPE(MSCJointNode);
 
+TVM_REGISTER_NODE_TYPE(MSCPrimNode);
+
 TVM_REGISTER_NODE_TYPE(WeightJointNode);
 
 TVM_REGISTER_NODE_TYPE(MSCGraphNode);
@@ -1296,8 +1433,9 @@ TVM_REGISTER_NODE_TYPE(WeightGraphNode);
 
 TVM_REGISTER_GLOBAL("msc.core.MSCTensor")
     .set_body_typed([](const String& name, const DataType& dtype, const String& layout,
-                       const Array<Integer>& shape, const String& alias) -> MSCTensor {
-      return MSCTensor(name, dtype, layout, shape, alias);
+                       const Array<Integer>& shape, const String& alias,
+                       const Array<String>& prims) -> MSCTensor {
+      return MSCTensor(name, dtype, layout, shape, alias, prims);
     });
 
 TVM_REGISTER_GLOBAL("msc.core.MSCTensorToJson")
@@ -1326,6 +1464,16 @@ TVM_REGISTER_GLOBAL("msc.core.MSCJoint")
                       weights);
     });
 
+TVM_REGISTER_GLOBAL("msc.core.MSCPrim")
+    .set_body_typed([](Integer index, const String& name, const String& optype,
+                       const Map<String, String>& attrs, const Array<MSCPrim>& parents) -> MSCPrim {
+      Array<BaseJoint> b_parents;
+      for (const auto& p : parents) {
+        b_parents.push_back(p);
+      }
+      return MSCPrim(index->value, name, optype, b_parents, attrs);
+    });
+
 TVM_REGISTER_GLOBAL("msc.core.WeightJoint")
     .set_body_typed([](Integer index, const String& name, const String& shared_ref,
                        const String& weight_type, const MSCTensor& weight,
@@ -1349,9 +1497,9 @@ TVM_REGISTER_GLOBAL("msc.core.WeightJointSetAttr")
 
 TVM_REGISTER_GLOBAL("msc.core.MSCGraph")
     .set_body_typed([](const String& name, const Array<MSCJoint>& nodes,
-                       const Array<String>& input_names,
-                       const Array<String>& output_names) -> MSCGraph {
-      return MSCGraph(name, nodes, input_names, output_names);
+                       const Array<String>& input_names, const Array<String>& output_names,
+                       const Array<MSCPrim>& prims) -> MSCGraph {
+      return MSCGraph(name, nodes, input_names, output_names, prims);
     });
 
 TVM_REGISTER_GLOBAL("msc.core.WeightGraph")
@@ -1371,6 +1519,11 @@ TVM_REGISTER_GLOBAL("msc.core.MSCGraphFindNode")
       return graph->FindNode(name);
     });
 
+TVM_REGISTER_GLOBAL("msc.core.MSCGraphFindPrim")
+    .set_body_typed([](const MSCGraph& graph, const String& name) -> MSCPrim {
+      return graph->FindPrim(name);
+    });
+
 TVM_REGISTER_GLOBAL("msc.core.MSCGraphHasTensor")
     .set_body_typed([](const MSCGraph& graph, const String& name) -> Bool {
       return Bool(graph->HasTensor(name));
