@@ -23,7 +23,6 @@
  */
 #include <tvm/ir/function.h>
 #include <tvm/relax/expr.h>
-#include <tvm/relay/function.h>
 #include <tvm/runtime/registry.h>
 #include <tvm/tir/function.h>
 
@@ -37,8 +36,6 @@ TVM_REGISTER_GLOBAL("ir.BaseFuncWithAttr")
     .set_body_typed([](BaseFunc func, String key, ObjectRef value) -> BaseFunc {
       if (func->IsInstance<tir::PrimFuncNode>()) {
         return WithAttr(Downcast<tir::PrimFunc>(std::move(func)), key, value);
-      } else if (func->IsInstance<relay::FunctionNode>()) {
-        return WithAttr(Downcast<relay::Function>(std::move(func)), key, value);
       } else if (func->IsInstance<relax::FunctionNode>()) {
         return WithAttr(Downcast<relax::Function>(std::move(func)), key, value);
       } else {
@@ -51,11 +48,6 @@ TVM_REGISTER_GLOBAL("ir.BaseFuncWithAttrs")
       if (func->IsInstance<tir::PrimFuncNode>()) {
         return WithAttrs(Downcast<tir::PrimFunc>(std::move(func)), attr_map);
       }
-      if (const auto* f = runtime::Registry::Get("relay.ir.FuncWithAttrs")) {
-        if (Optional<BaseFunc> ret = (*f)(func, attr_map)) {
-          return ret.value();
-        }
-      }
       if (const auto* f = runtime::Registry::Get("relax.FuncWithAttrs")) {
         if (Optional<BaseFunc> ret = (*f)(func, attr_map)) {
           return ret.value();
@@ -68,8 +60,6 @@ TVM_REGISTER_GLOBAL("ir.BaseFuncWithoutAttr")
     .set_body_typed([](BaseFunc func, String key) -> BaseFunc {
       if (func->IsInstance<tir::PrimFuncNode>()) {
         return WithoutAttr(Downcast<tir::PrimFunc>(std::move(func)), key);
-      } else if (func->IsInstance<relay::FunctionNode>()) {
-        return WithoutAttr(Downcast<relay::Function>(std::move(func)), key);
       } else if (func->IsInstance<relax::FunctionNode>()) {
         return WithoutAttr(Downcast<relax::Function>(std::move(func)), key);
       } else {
