@@ -333,7 +333,7 @@ IRModule Pass::AssertImmutableModule(const IRModule& mod, const PassNode* node,
 /*!
  * \brief Module-level passes are designed to implement global
  * analysis/optimizations, i.e. interprocedural optimizations (IPO), etc. Passes
- * at this level have the full control of a given Relay program including
+ * at this level have the full control of a given Relax program including
  * addition and deletion of functions.
  */
 class ModulePassNode : public PassNode {
@@ -465,8 +465,6 @@ Pass GetPass(const String& pass_name) {
   if (pass_name.operator std::string().find("transform.") != std::string::npos) {
     f = Registry::Get(pass_name);
   } else if ((f = Registry::Get("transform." + pass_name))) {
-    // pass
-  } else if ((f = Registry::Get("relay._transform." + pass_name))) {
   }
   ICHECK(f != nullptr) << "Cannot use " << pass_name << " to create the pass";
   return (*f)();
@@ -686,11 +684,6 @@ TVM_REGISTER_GLOBAL("transform.OverrideInstruments")
 
 Pass PrintIR(String header, bool show_meta_data) {
   auto pass_func = [header, show_meta_data](IRModule mod, const PassContext& ctx) {
-    if (const auto* f = runtime::Registry::Get("relay.ir.PrintIR")) {
-      if ((*f)(mod, header, show_meta_data)) {
-        return mod;
-      }
-    }
     LOG(INFO) << "PrintIR(" << header << "):\n" << mod;
     return mod;
   };
