@@ -129,13 +129,13 @@ void FindSampleVectorize(const Trace& trace, std::vector<Instruction>* inst,
       ICHECK_EQ(inst->outputs.size(), 1);
       if (annotated.count(inst->outputs[0].get())) {
         ICHECK_EQ(inst->attrs.size(), 2);
-        std::vector<double> probs =
-            support::AsVector<FloatImm, double>(Downcast<Array<FloatImm>>(inst->attrs[1]));
+        std::vector<double> probs = support::AsVector<runtime::Float, double>(
+            Downcast<Array<runtime::Float>>(inst->attrs[1]));
         if (probs.size() == 1) {
           // Skip mutating the sampling instructions who have only single candidate.
           continue;
         }
-        const auto* d = TVM_TYPE_AS(decision, IntImmNode);
+        const auto* d = TVM_TYPE_AS(decision, runtime::Int::ContainerType);
         instructions.push_back(inst);
         decisions.push_back(d->value);
       }
