@@ -26,8 +26,6 @@
 #include <tvm/ir/attrs.h>
 #include <tvm/node/reflection.h>
 #include <tvm/node/serialization.h>
-#include <tvm/relay/expr.h>
-#include <tvm/relay/expr_functor.h>
 #include <tvm/runtime/ndarray.h>
 #include <tvm/runtime/packed_func.h>
 #include <tvm/runtime/registry.h>
@@ -136,21 +134,6 @@ class NodeIndexer : public AttrVisitor {
           MakeIndex(const_cast<Object*>(kv.second.get()));
         }
       }
-    } else if (node->IsInstance<relay::LetNode>()) {
-      auto pre_visit = [this](const relay::LetNode* op) {
-        MakeNodeIndex(const_cast<Object*>(static_cast<const Object*>(op)));
-        MakeIndex(const_cast<Object*>(static_cast<const Object*>(op->var.get())));
-        MakeIndex(const_cast<Object*>(static_cast<const Object*>(op->value.get())));
-        MakeIndex(const_cast<Object*>(static_cast<const Object*>(op->span.get())));
-        MakeIndex(const_cast<Object*>(static_cast<const Object*>(op->checked_type_.get())));
-        if (!op->body.as<relay::LetNode>()) {
-          MakeIndex(const_cast<Object*>(static_cast<const Object*>(op->body.get())));
-        }
-      };
-      auto post_visit = [](const relay::LetNode* op) {};
-      if (!reflection_->GetReprBytes(node, nullptr)) {
-        relay::ExpandANormalForm(static_cast<relay::LetNode*>(node), pre_visit, post_visit);
-      }
     } else {
       // if the node already have repr bytes, no need to visit Attrs.
       if (!reflection_->GetReprBytes(node, nullptr)) {
