@@ -72,10 +72,12 @@ inline std::string DType2String(const tvm::DataType dtype) {
   std::ostringstream os;
   if (dtype.is_float()) {
     os << "float";
-  } else if (dtype.is_e4m3_float8()) {
-    os << "e4m3_float";
-  } else if (dtype.is_e5m2_float8()) {
-    os << "e5m2_float";
+  } else if (dtype.is_float8_e4m3fn()) {
+    return "float8_e4m3fn";
+  } else if (dtype.is_float8_e5m2()) {
+    return "float8_e5m2";
+  } else if (dtype.is_float4_e2m1fn()) {
+    return "float4_e2m1fn";
   } else if (dtype.is_int()) {
     os << "int";
   } else if (dtype.is_uint()) {
@@ -111,19 +113,31 @@ inline bool IsOp(const CallNode* call, const std::string& op_name) {
  * The function must contain exactly one call to such op.
  * \param f The function to look for an op.
  * \param op_name The name of the op
- * \return A call node which calls an op with the given name
+ * \return A call node which calls an op with the given name or nullptr if not
  */
-inline const CallNode* GetOpInFunction(Function f, const std::string& op_name) {
+inline const CallNode* TryGetOpInFunction(Function f, const std::string& op_name) {
   auto local_bindings = AnalyzeVar2Value(f);
   for (const auto& entry : local_bindings) {
     if (auto call = entry.second.as<CallNode>(); call && backend::IsOp(call, op_name)) {
       return call;
     }
   }
-  LOG(FATAL) << op_name << " not found in the function:\n" << f;
   return nullptr;
 }
 
+/*!
+ * \brief Return a call node within the function which calls an op with the given name
+ * The function must contain exactly one call to such op.
+ * \param f The function to look for an op.
+ * \param op_name The name of the op
+ * \return A call node which calls an op with the given name
+ */
+inline const CallNode* GetOpInFunction(Function f, const std::string& op_name) {
+  const CallNode* op = TryGetOpInFunction(f, op_name);
+  ICHECK(op) << op_name << " not found in the function:\n" << f;
+  return op;
+}
+
 /*!
  * \brief Extract indices of the argument patterns in the function parameter list.
  * Each composite function pattern can register a mapping between variable names and the
@@ -149,6 +163,14 @@ std::string to_str(const Type& value) {
   return os.str();
 }
 
+/*!
+ * \brief Utility function to find the string pattern in string str
+ * \param str the main string to check the pattern
+ * \param pattern the pattern to check in the main string
+ * \return return true if the main string ends with pattern, false otherwise
+ */
+bool EndsWithPattern(const std::string& str, const std::string& pattern);
+
 }  // namespace backend
 }  // namespace relax
 }  // namespace tvm
