@@ -594,7 +594,7 @@ bool DFPatternMatcher::VisitDFPattern_(const PrimArrPatternNode* op, const Expr&
 bool DFPatternMatcher::VisitDFPattern_(const DataTypePatternNode* op, const Expr& expr) {
   // no need to jump, as var.dtype == value.dtype
   auto expr_type = expr.as<ExprNode>()->checked_type();
-  if (const DynTensorTypeNode* tensor_type = expr_type.as<DynTensorTypeNode>()) {
+  if (const TensorTypeNode* tensor_type = expr_type.as<TensorTypeNode>()) {
     return (StructuralEqual()(op->dtype, tensor_type->dtype)) && VisitDFPattern(op->pattern, expr);
   }
   return false;
