@@ -32,6 +32,7 @@
  * Any binding blocks that are left empty will be removed by the normalizer.
  */
 
+#include <tvm/ir/analysis.h>
 #include <tvm/relax/analysis.h>
 #include <tvm/relax/expr.h>
 #include <tvm/relax/expr_functor.h>
@@ -42,89 +43,40 @@
 namespace tvm {
 namespace relax {
 
-/**
- * \brief Detects all the functions that can be possibly called by entry function.
- */
-class CallTracer : public ExprVisitor {
- public:
-  explicit CallTracer(IRModule mod) : mod_{mod}, called_funcs_{}, visiting_{} {}
-
-  void VisitExpr_(const GlobalVarNode* op) final {
-    auto gvar = GetRef<GlobalVar>(op);
-    called_funcs_.insert(gvar);
-    if (auto func = mod_->functions.Get(gvar)) {
-      if (const auto* function_node = func.as<FunctionNode>()) {
-        VisitExpr(GetRef<Function>(function_node));
-      }
-      // else: Don't visit PrimFuncs -- we don't need to collect any tir.Calls therein.
-    } else {
-      // The GlobalVar is not contained in the IRModule.  While the
-      // input IRModule is ill-formed, this specific case is allowed
-      // for use with `relax.transform.ApplyPassToFunction`.  If this
-      // occurs, DCE should not remove any internal functions from the
-      // IRModule, as their removal is only valid if we have a
-      // complete call graph.
-      all_callees_found_ = false;
-    }
-  }
-
-  void VisitExpr_(const CallNode* call_node) final { ExprVisitor::VisitExpr_(call_node); }
-
-  void VisitExpr_(const FunctionNode* func_node) final {
-    auto func = GetRef<Function>(func_node);
-    if (visiting_.find(func) == visiting_.end()) {
-      visiting_.insert(func);
-      for (auto param : func_node->params) {
-        ExprVisitor::VisitExpr(param);
-      }
-      ExprVisitor::VisitExpr(func_node->body);
-    }
-  }
-
-  void Trace(std::string entry) {
-    called_funcs_.insert(mod_->GetGlobalVar(entry));
-    auto main_func = mod_->Lookup(entry);
-    VisitExpr(main_func);
-  }
-
-  /* \brief Check if a function is unreachable
-   *
-   * \param gvar The function to be checked
-   *
-   * \return True if the function can be proven to be unreachable,
-   * either directly or indirectly, from an external caller.
-   * Otherwise, false.
-   */
-  bool CheckIfProvablyUnreachable(const GlobalVar& gvar) const {
-    return all_callees_found_ && !called_funcs_.count(gvar);
-  }
-
- private:
-  IRModule mod_;
-
-  /* \brief Whether all callees could be located within the IRModule */
-  bool all_callees_found_{true};
-
-  // Record the names of all encountered functions.
-  std::unordered_set<GlobalVar> called_funcs_;
-
-  // Record the expressions that are being visited.
-  std::unordered_set<Expr, ObjectPtrHash, ObjectPtrEqual> visiting_;
-};
-
 IRModule RemoveUnusedFunctions(IRModule mod, const std::unordered_set<GlobalVar>& entry_funcs) {
-  CallTracer tracer(mod);
-  for (const auto& gvar : entry_funcs) {
-    tracer.VisitExpr(gvar);
+  auto call_map = ir::CollectCallMap(mod);
+
+  std::unordered_set<GlobalVar> reachable = entry_funcs;
+  std::vector<GlobalVar> to_visit(entry_funcs.begin(), entry_funcs.end());
+  bool all_callees_in_module = true;
+
+  while (to_visit.size()) {
+    GlobalVar visiting = to_visit.back();
+    to_visit.pop_back();
+
+    if (auto it = call_map.find(visiting); it != call_map.end()) {
+      for (GlobalVar callee : (*it).second) {
+        if (!reachable.count(callee)) {
+          reachable.insert(callee);
+          to_visit.push_back(callee);
+        }
+      }
+    } else {
+      all_callees_in_module = false;
+    }
+  }
+
+  if (!all_callees_in_module) {
+    return mod;
   }
 
   std::vector<GlobalVar> to_remove;
-  for (const auto& kv : mod->functions) {
+  for (const auto& [gvar, func] : mod->functions) {
     // The tracer contains all user-provided entry functions, all
     // externally-callable functions, and anything that is directly or
     // indirectly accessible from an entry function.
-    if (tracer.CheckIfProvablyUnreachable(kv.first)) {
-      to_remove.push_back(kv.first);
+    if (!reachable.count(gvar)) {
+      to_remove.push_back(gvar);
     }
   }
 
