@@ -181,6 +181,25 @@ NLayout InitialNLayout(const StructInfo& sinfo);
  */
 NLayout InitialNLayout(const Expr& expr);
 
+/*!
+ * \brief Transposing given layout with subindexing
+ * \param ref The layout to be transformed.
+ * \param src The source layout.
+ * \param dst The destination layout.
+ * \return The transposed dst layout.
+ */
+Layout TransposeSubLayoutLike(const Layout& ref, const Layout& src, const Layout& desired);
+
+/*!
+ * \brief Transposing given layout in string format with subindexing
+ * \param ref The layout to be transformed.
+ * \param src The source layout.
+ * \param dst The destination layout.
+ * \return The transposed dst layout.
+ */
+std::string TransposeSubLayoutStrLike(const std::string ref_str, const std::string& src_str,
+                                      const std::string& desired_str);
+
 /*!
  * \brief Transpose the input layout  like the src layout to the dst layout.
  * \param input The input layout.
