@@ -119,7 +119,10 @@ struct BaseCollectInfo {
     Function func(params, body, GetStructInfo(tuple_var));
     func = WithAttr(func, attr::kNumInput, Integer(0));
     func = CopyWithNewVars(func);
+    func = BundleModelParams(func);
     func = Downcast<Function>(CanonicalizeBindings(func));
+    func = Downcast<Function>(RemoveAllUnused(func));
+
     return func;
   }
 };
@@ -725,11 +728,12 @@ std::vector<std::pair<GlobalVar, Function>> GetTargetFunctions(
       target_functions.push_back({gvar.value(), func.value()});
     }
   } else {
-    // Get all the functions that have the `num_input` attribute.
+    // Get all the functions that have the `num_input` attribute, and
+    // are not already the result of `LiftTransformParams`.
     for (const auto& [gvar, func] : mod->functions) {
       if (func->IsInstance<FunctionNode>()) {
         auto opt_num_input = func->GetAttr<Integer>(attr::kNumInput);
-        if (opt_num_input) {
+        if (opt_num_input && !ends_with(gvar->name_hint, "transform_params")) {
           target_functions.emplace_back(gvar, Downcast<Function>(func));
         }
       }
@@ -748,7 +752,6 @@ namespace transform {
 
 Pass PartitionTransformParams(Variant<Bool, Array<String>> shared_transform) {
   auto pass_func = [=](IRModule mod, PassContext pc) {
-    IRModule updates;
     std::optional<GlobalCollectInfo> global_collect_info;
 
     CHECK(shared_transform.defined()) << "shared_transform is not defined";
@@ -772,24 +775,41 @@ Pass PartitionTransformParams(Variant<Bool, Array<String>> shared_transform) {
       local_collect_info[gvar] = info;
     }
 
+    IRModule updated_runtime_functions;
+
     for (const auto& [gvar, info] : local_collect_info) {
       auto new_runtime_func = info.MakeRuntimeFunction();
-      updates->Add(gvar, new_runtime_func);
+      updated_runtime_functions->Add(gvar, new_runtime_func);
     }
 
+    Map<String, Function> lifted_transform_functions;
     if (global_collect_info.has_value()) {
       auto global_transform = global_collect_info.value().MakeCompileTimeFunc();
-      updates->Add(GlobalVar("transform_params"), global_transform);
+      lifted_transform_functions.Set("transform_params", global_transform);
     } else {
       for (const auto& [gvar, info] : local_collect_info) {
         // transform_params is emitted for each function if global lifting is not enabled
-        updates->Add(GlobalVar(gvar->name_hint + "_transform_params"),
-                     info.MakeCompileTimeFunction());
+        lifted_transform_functions.Set(gvar->name_hint + "_transform_params",
+                                       info.MakeCompileTimeFunction());
       }
     }
 
-    if (updates->functions.size()) {
-      mod.CopyOnWrite()->Update(updates);
+    if (updated_runtime_functions->functions.size() || lifted_transform_functions.size()) {
+      auto write_ptr = mod.CopyOnWrite();
+      write_ptr->Update(updated_runtime_functions);
+
+      for (auto [name, transform] : lifted_transform_functions) {
+        if (auto opt = write_ptr->global_var_map_.Get(name)) {
+          auto old_gvar = opt.value();
+          auto old_transform = Downcast<Function>(write_ptr->Lookup(old_gvar));
+          write_ptr->Remove(old_gvar);
+
+          transform = ComposeFunctions(old_transform, transform);
+        }
+        GlobalVar new_gvar(name);
+        UpdateStructInfo(new_gvar, GetStructInfo(transform));
+        write_ptr->Add(new_gvar, transform);
+      }
     }
 
     return mod;
@@ -817,7 +837,6 @@ Pass LiftTransformParams(Variant<Bool, Array<String>> shared_transform) {
         std::string func_name = gvar->name_hint;
         if (ends_with(func_name, "transform_params")) {
           func = WithAttr(func, tvm::attr::kGlobalSymbol, gvar->name_hint);
-          func = BundleModelParams(func);
           if (pc->GetConfig<Bool>(kLiftTransformConsumeParams).value_or(Bool(false))) {
             func = Downcast<Function>(ConsumeBundledParams()(func));
           }
