@@ -164,8 +164,10 @@ static const uint64_t kTVMCLMLTuningCacheMagic = 0x434C4D4C54554E45;
 
 #define DEBUG_MEMORY_ALLOC false
 #define DEBUG_STATS false
+#define DEBUG_CLML false
 #define LOG_MEM LOG_IF(WARNING, DEBUG_MEMORY_ALLOC)
 #define LOG_STATS LOG_IF(WARNING, DEBUG_STATS)
+#define LOG_CLML LOG_IF(WARNING, DEBUG_CLML)
 
 namespace tvm {
 namespace runtime {
@@ -228,6 +230,18 @@ class CLMLThreadEntry {
   static CLMLThreadEntry* ThreadLocal();
 };
 
+/*!
+ * \brief Node descriptor to hold various information related to a Node.
+ */
+struct NodeDescriptor {
+  std::shared_ptr<cl_ml_tensor_memory_desc_qcom> tensor_desc = nullptr;
+  JSONGraphNode node;
+  // Check the flag and them pick the layout.
+  bool custom_layout = false;
+  cl_ml_tensor_layout_qcom layout;
+  cl_ml_tensor_usage_qcom usage = CL_TENSOR_USAGE_INVALID_QCOM;
+};
+
 /*!
  * \brief CLML objects we cache in order to avoid needing to construct
  * a new layer each time.
@@ -235,6 +249,8 @@ class CLMLThreadEntry {
 struct CachedLayer {
   /* List of all created CLML operation handles in graph */
   std::vector<cl_ml_op_qcom> function;
+  /* Map of function and original JsonNode */
+  std::map<cl_ml_op_qcom, std::pair<int, JSONGraphNode>> op_node_map;
   /* The input tensor map  */
   std::map<int, std::shared_ptr<cl_ml_tensor_memory_desc_qcom>> inputs;
   /* A place holder Tensor representing TVM NDArray as CLML Tensor */
@@ -245,9 +261,8 @@ struct CachedLayer {
   std::vector<std::shared_ptr<cl_ml_tensor_memory_desc_qcom>> out_placeholder;
   /* Tensor shape exception list while returning from CLML Subgraph */
   std::map<int, std::vector<size_t>> out_shapes;
-  /* Map of all tensors which need backing memory allocation */
-  std::map<int, std::pair<std::shared_ptr<cl_ml_tensor_memory_desc_qcom>, JSONGraphNode>>
-      storage_map;
+  /* Map of nodeid and descriptors */
+  std::map<int, struct NodeDescriptor> storage_map;
   /* Tensor memory descriptors list to set after backing memory allocation */
   std::vector<cl_ml_tensor_memory_desc_qcom> tensorMemDescs;
   cl_ml_tensor_mem_desc_set_qcom descriptorSet;
