@@ -26,8 +26,6 @@
 
 #include <dmlc/io.h>
 #include <dmlc/json.h>
-#include <tvm/runtime/executor_info.h>
-#include <tvm/runtime/metadata.h>
 #include <tvm/runtime/module.h>
 #include <tvm/runtime/ndarray.h>
 #include <tvm/runtime/packed_func.h>
@@ -50,15 +48,6 @@ inline String get_name_mangled(const String& module_name, const String& name) {
   return ss.str();
 }
 
-/*!
- * \brief Create a metadata module object.
- *
- * \param metadata Exported metadata structure.
- *
- * \return The created metadata module.
- */
-Module MetadataModuleCreate(metadata::Metadata metadata);
-
 namespace launch_param {
 
 /*! \brief A tag to specify whether or not dynamic shared memory is used */
