@@ -16,6 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
+#include <tvm/ir/module.h>
 #include <tvm/tir/expr.h>
 #include <tvm/tir/op.h>
 #include <tvm/tir/stmt.h>
@@ -174,12 +175,6 @@ TVM_STATIC_IR_FUNCTOR(ReprLegacyPrinter, vtable)
       (*p) << "TupleTypeNode(" << node->fields << ")";
     });
 
-TVM_STATIC_IR_FUNCTOR(ReprLegacyPrinter, vtable)
-    .set_dispatch<IncompleteTypeNode>([](const ObjectRef& ref, ReprLegacyPrinter* p) {
-      auto* node = static_cast<const IncompleteTypeNode*>(ref.get());
-      (*p) << "IncompleteTypeNode(" << node->kind << ", " << node << ")";
-    });
-
 TVM_STATIC_IR_FUNCTOR(ReprLegacyPrinter, vtable)
     .set_dispatch<DictAttrsNode>([](const ObjectRef& node, ReprLegacyPrinter* p) {
       auto* op = static_cast<const DictAttrsNode*>(node.get());
@@ -198,29 +193,10 @@ TVM_STATIC_IR_FUNCTOR(ReprLegacyPrinter, vtable)
       (*p) << "IRModule(" << node->functions << ")";
     });
 
-TVM_STATIC_IR_FUNCTOR(ReprLegacyPrinter, vtable)
-    .set_dispatch<TypeVarNode>([](const ObjectRef& ref, ReprLegacyPrinter* p) {
-      auto* node = static_cast<const TypeVarNode*>(ref.get());
-      (*p) << "TypeVar(" << node->name_hint << ", " << node->kind << ")";
-    });
-
-TVM_STATIC_IR_FUNCTOR(ReprLegacyPrinter, vtable)
-    .set_dispatch<GlobalTypeVarNode>([](const ObjectRef& ref, ReprLegacyPrinter* p) {
-      auto* node = static_cast<const GlobalTypeVarNode*>(ref.get());
-      (*p) << "GlobalTypeVar(" << node->name_hint << ", " << node->kind << ")";
-    });
-
 TVM_STATIC_IR_FUNCTOR(ReprLegacyPrinter, vtable)
     .set_dispatch<FuncTypeNode>([](const ObjectRef& ref, ReprLegacyPrinter* p) {
       auto* node = static_cast<const FuncTypeNode*>(ref.get());
-      (*p) << "FuncType(" << node->type_params << ", " << node->arg_types << ", " << node->ret_type
-           << ", " << node->type_constraints << ")";
-    });
-
-TVM_STATIC_IR_FUNCTOR(ReprLegacyPrinter, vtable)
-    .set_dispatch<RelayRefTypeNode>([](const ObjectRef& ref, ReprLegacyPrinter* p) {
-      auto* node = static_cast<const RelayRefTypeNode*>(ref.get());
-      (*p) << "RelayRefTypeNode(" << node->value << ")";
+      (*p) << "FuncType(" << node->arg_types << ", " << node->ret_type << ")";
     });
 
 }  // namespace tvm
@@ -545,9 +521,6 @@ TVM_STATIC_IR_FUNCTOR(ReprLegacyPrinter, vtable)
       (*p) << ")";
     });
 
-TVM_STATIC_IR_FUNCTOR(ReprLegacyPrinter, vtable)
-    .set_dispatch<AnyNode>([](const ObjectRef& node, ReprLegacyPrinter* p) { (*p) << "?"; });
-
 TVM_STATIC_IR_FUNCTOR(ReprLegacyPrinter, vtable)
     .set_dispatch<BufferLoadNode>([](const ObjectRef& node, ReprLegacyPrinter* p) {
       auto* op = static_cast<const BufferLoadNode*>(node.get());
