@@ -75,7 +75,11 @@ TVM_STATIC_IR_FUNCTOR(IRDocsifier, vtable)
     .set_dispatch<tvm::IntImm>(                                             //
         "relax", [](tvm::IntImm n, ObjectPath n_p, IRDocsifier d) -> Doc {  //
           // TODO(@junrushao): support non-int64 cases
-          return LiteralDoc::Int(n->value, n_p);
+          if (n->dtype.is_bool()) {
+            return LiteralDoc::Boolean(n->value, n_p);
+          } else {
+            return LiteralDoc::Int(n->value, n_p);
+          }
         });
 
 TVM_STATIC_IR_FUNCTOR(IRDocsifier, vtable)
