@@ -115,26 +115,10 @@
 #define TVM_INFO_USE_LLVM "NOT-FOUND"
 #endif
 
-#ifndef TVM_INFO_USE_STACKVM_RUNTIME
-#define TVM_INFO_USE_STACKVM_RUNTIME "NOT-FOUND"
-#endif
-
-#ifndef TVM_INFO_USE_GRAPH_EXECUTOR
-#define TVM_INFO_USE_GRAPH_EXECUTOR "NOT-FOUND"
-#endif
-
-#ifndef TVM_INFO_USE_PROFILER
-#define TVM_INFO_USE_PROFILER "NOT-FOUND"
-#endif
-
 #ifndef TVM_INFO_USE_OPENMP
 #define TVM_INFO_USE_OPENMP "NOT-FOUND"
 #endif
 
-#ifndef TVM_INFO_USE_RELAY_DEBUG
-#define TVM_INFO_USE_RELAY_DEBUG "NOT-FOUND"
-#endif
-
 #ifndef TVM_INFO_DEBUG_WITH_ABI_CHANGE
 #define TVM_INFO_DEBUG_WITH_ABI_CHANGE "NOT-FOUND"
 #endif
@@ -159,10 +143,6 @@
 #define TVM_INFO_HIDE_PRIVATE_SYMBOLS "NOT-FOUND"
 #endif
 
-#ifndef TVM_INFO_USE_TF_TVMDSOOP
-#define TVM_INFO_USE_TF_TVMDSOOP "NOT-FOUND"
-#endif
-
 #ifndef TVM_INFO_USE_FALLBACK_STL_MAP
 #define TVM_INFO_USE_FALLBACK_STL_MAP "NOT-FOUND"
 #endif
@@ -247,10 +227,6 @@
 #define TVM_INFO_USE_COREML "NOT-FOUND"
 #endif
 
-#ifndef TVM_INFO_USE_TARGET_ONNX
-#define TVM_INFO_USE_TARGET_ONNX "NOT-FOUND"
-#endif
-
 #ifndef TVM_INFO_USE_ARM_COMPUTE_LIB
 #define TVM_INFO_USE_ARM_COMPUTE_LIB "NOT-FOUND"
 #endif
@@ -310,7 +286,6 @@ TVM_DLL Map<String, String> GetLibInfo() {
       {"SUMMARIZE", TVM_INFO_SUMMARIZE},
       {"TVM_CXX_COMPILER_PATH", TVM_CXX_COMPILER_PATH},
       {"USE_ALTERNATIVE_LINKER", TVM_INFO_USE_ALTERNATIVE_LINKER},
-      {"USE_AOT_EXECUTOR", TVM_INFO_USE_AOT_EXECUTOR},
       {"USE_ARM_COMPUTE_LIB_GRAPH_EXECUTOR", TVM_INFO_USE_ARM_COMPUTE_LIB_GRAPH_EXECUTOR},
       {"USE_ARM_COMPUTE_LIB", TVM_INFO_USE_ARM_COMPUTE_LIB},
       {"USE_BLAS", TVM_INFO_USE_BLAS},
@@ -331,8 +306,6 @@ TVM_DLL Map<String, String> GetLibInfo() {
       {"USE_AMX", TVM_INFO_USE_AMX},
       {"USE_DNNL", TVM_INFO_USE_DNNL},
       {"USE_FALLBACK_STL_MAP", TVM_INFO_USE_FALLBACK_STL_MAP},
-      {"USE_GRAPH_EXECUTOR_CUDA_GRAPH", TVM_INFO_USE_GRAPH_EXECUTOR_CUDA_GRAPH},
-      {"USE_GRAPH_EXECUTOR", TVM_INFO_USE_GRAPH_EXECUTOR},
       {"USE_GTEST", TVM_INFO_USE_GTEST},
       {"USE_HEXAGON", TVM_INFO_USE_HEXAGON},
       {"USE_HEXAGON_RPC", TVM_INFO_USE_HEXAGON_RPC},
@@ -357,10 +330,7 @@ TVM_DLL Map<String, String> GetLibInfo() {
       {"USE_OPENCL_GTEST", TVM_INFO_USE_OPENCL_GTEST},
       {"USE_OPENMP", TVM_INFO_USE_OPENMP},
       {"USE_PAPI", TVM_INFO_USE_PAPI},
-      {"USE_PROFILER", TVM_INFO_USE_PROFILER},
-      {"USE_PT_TVMDSOOP", TVM_INFO_USE_PT_TVMDSOOP},
       {"USE_RANDOM", TVM_INFO_USE_RANDOM},
-      {"USE_RELAY_DEBUG", TVM_INFO_USE_RELAY_DEBUG},
       {"TVM_DEBUG_WITH_ABI_CHANGE", TVM_INFO_TVM_DEBUG_WITH_ABI_CHANGE},
       {"TVM_LOG_BEFORE_THROW", TVM_INFO_TVM_LOG_BEFORE_THROW},
       {"USE_ROCBLAS", TVM_INFO_USE_ROCBLAS},
@@ -373,22 +343,18 @@ TVM_DLL Map<String, String> GetLibInfo() {
       {"USE_SORT", TVM_INFO_USE_SORT},
       {"USE_SPIRV_KHR_INTEGER_DOT_PRODUCT", TVM_INFO_USE_SPIRV_KHR_INTEGER_DOT_PRODUCT},
       {"USE_STACKVM_RUNTIME", TVM_INFO_USE_STACKVM_RUNTIME},
-      {"USE_TARGET_ONNX", TVM_INFO_USE_TARGET_ONNX},
       {"USE_TENSORFLOW_PATH", TVM_INFO_USE_TENSORFLOW_PATH},
       {"USE_TENSORRT_CODEGEN", TVM_INFO_USE_TENSORRT_CODEGEN},
       {"USE_TENSORRT_RUNTIME", TVM_INFO_USE_TENSORRT_RUNTIME},
-      {"USE_TF_TVMDSOOP", TVM_INFO_USE_TF_TVMDSOOP},
       {"USE_TFLITE", TVM_INFO_USE_TFLITE},
       {"USE_THREADS", TVM_INFO_USE_THREADS},
       {"USE_THRUST", TVM_INFO_USE_THRUST},
       {"USE_CURAND", TVM_INFO_USE_CURAND},
-      {"USE_VITIS_AI", TVM_INFO_USE_VITIS_AI},
       {"USE_VULKAN", TVM_INFO_USE_VULKAN},
       {"USE_CLML", TVM_INFO_USE_CLML},
       {"TVM_CLML_VERSION", TVM_INFO_USE_TVM_CLML_VERSION},
       {"USE_CLML_GRAPH_EXECUTOR", TVM_INFO_USE_CLML_GRAPH_EXECUTOR},
       {"USE_UMA", TVM_INFO_USE_UMA},
-      {"USE_VERILATOR", TVM_INFO_USE_VERILATOR},
       {"USE_MSC", TVM_INFO_USE_MSC},
       {"USE_CCACHE", TVM_INFO_USE_CCACHE},
       {"USE_NVSHMEM", TVM_INFO_USE_NVSHMEM},
