@@ -59,8 +59,6 @@
 #include <unordered_map>
 #include <unordered_set>
 
-#include "../func_registry_generator.h"
-#include "../metadata_utils.h"
 #include "llvm_instance.h"
 
 namespace tvm {
@@ -974,377 +972,6 @@ llvm::Value* CodeGenCPU::RuntimeTVMParallelBarrier() {
   return GetContextPtr(gv_tvm_parallel_barrier_);
 }
 
-/*! \brief Defines LLVM Types for each Metadata member type. */
-struct MetadataLlvmTypes {
-  llvm::Type* t_float64;
-  llvm::Type* t_uint8;
-  llvm::Type* t_int64;
-  llvm::Type* t_bool;
-  llvm::Type* t_cstring;
-  llvm::Type* t_void_p;
-  llvm::StructType* t_data_type;
-
-  /*! \brief Maps a MetadataBase subclass' type_key to its corresponding LLVM StructType. */
-  ::std::unordered_map<std::string, llvm::StructType*> structs_by_type_key;
-};
-
-class MetadataTypeDefiner : public AttrVisitor {
- public:
-  MetadataTypeDefiner(llvm::LLVMContext* ctx, struct MetadataLlvmTypes* llvm_types)
-      : ctx_{ctx}, llvm_types_{llvm_types} {}
-
-  void Visit(const char* key, double* value) final {
-    elements_.emplace_back(llvm_types_->t_float64);
-  }
-  void Visit(const char* key, int64_t* value) final {
-    elements_.emplace_back(llvm_types_->t_int64);
-  }
-  void Visit(const char* key, uint64_t* value) final {
-    elements_.emplace_back(llvm_types_->t_int64);
-  }
-  void Visit(const char* key, int* value) final { elements_.emplace_back(llvm_types_->t_int64); }
-  void Visit(const char* key, bool* value) final { elements_.emplace_back(llvm_types_->t_bool); }
-  void Visit(const char* key, std::string* value) final {
-    elements_.emplace_back(llvm_types_->t_cstring);
-  }
-  void Visit(const char* key, void** value) final { elements_.emplace_back(llvm_types_->t_void_p); }
-  void Visit(const char* key, DataType* value) final {
-    elements_.emplace_back(llvm_types_->t_data_type);
-  }
-  void Visit(const char* key, runtime::NDArray* value) final {
-    elements_.emplace_back(llvm_types_->t_int64);
-    elements_.emplace_back(llvm_types_->t_void_p);
-  }
-
- private:
-  void VisitMetadataBase(runtime::metadata::MetadataBase metadata) {
-    elements_.emplace_back(llvm::PointerType::getUnqual(
-        llvm::StructType::create(*ctx_, metadata->get_c_struct_name())));
-    if (visited_.find(metadata->get_c_struct_name()) != visited_.end()) {
-      return;
-    }
-
-    if (to_visit_.find(metadata->get_c_struct_name()) != to_visit_.end()) {
-      return;
-    }
-    to_visit_[metadata->get_c_struct_name()] = metadata;
-  }
-
- public:
-  using MetadataKind = runtime::metadata::MetadataKind;
-
-  void VisitArray(const runtime::metadata::MetadataArrayNode* arr) {
-    switch (arr->kind) {
-      case MetadataKind::kUint64:  // LLVM encodes signed and unsigned with same types.
-      case MetadataKind::kInt64:
-        elements_.emplace_back(llvm::PointerType::getUnqual(llvm_types_->t_int64));
-        break;
-      case MetadataKind::kBool:
-        elements_.emplace_back(llvm::PointerType::getUnqual(llvm_types_->t_bool));
-        break;
-      case MetadataKind::kString:
-        elements_.emplace_back(llvm::PointerType::getUnqual(llvm_types_->t_cstring));
-        break;
-      case MetadataKind::kHandle:
-        CHECK(false) << "Do not support handle";
-        break;
-      case MetadataKind::kMetadata:
-        if (llvm_types_->structs_by_type_key.count(arr->type_key)) {
-          elements_.emplace_back(
-              llvm::PointerType::getUnqual(llvm_types_->structs_by_type_key[arr->type_key]));
-        }
-        break;
-      default:
-        CHECK(false) << "Unsupported metadata kind " << arr->kind;
-        break;
-    }
-  }
-
-  void Visit(const char* key, ObjectRef* value) final {
-    const runtime::metadata::MetadataArrayNode* arr =
-        value->as<runtime::metadata::MetadataArrayNode>();
-    if (arr != nullptr) {
-      VisitArray(arr);
-    } else {
-      elements_.emplace_back(
-          llvm::PointerType::getUnqual(llvm_types_->structs_by_type_key[(*value)->GetTypeKey()]));
-    }
-  }
-
-  void DefineType(runtime::metadata::MetadataBase metadata) {
-    ICHECK(elements_.empty());
-    ReflectionVTable::Global()->VisitAttrs(metadata.operator->(), this);
-    llvm_types_->structs_by_type_key[metadata->GetTypeKey()] =
-        llvm::StructType::create(*ctx_, elements_, metadata->get_c_struct_name());
-    elements_.clear();
-  }
-
-  llvm::LLVMContext* ctx_;
-  struct MetadataLlvmTypes* llvm_types_;
-  ::std::unordered_set<::std::string> visited_;
-  ::std::unordered_map<::std::string, runtime::metadata::MetadataBase> to_visit_;
-  ::std::vector<llvm::Type*> elements_;
-};
-
-class MetadataSerializerLLVM : public AttrVisitor {
-  using MetadataKind = runtime::metadata::MetadataKind;
-
- public:
-  MetadataSerializerLLVM(CodeGenLLVM* codegen, struct MetadataLlvmTypes* llvm_types)
-      : codegen_{codegen}, llvm_types_{llvm_types} {}
-
-  void Visit(const char* key, double* value) final {
-    elements_.back().emplace_back(llvm::ConstantFP::get(llvm_types_->t_float64, *value));
-  }
-  void Visit(const char* key, int64_t* value) final {
-    elements_.back().emplace_back(llvm::ConstantInt::get(
-        llvm_types_->t_int64, static_cast<uint64_t>(*value), true /* isSigned */));
-  }
-  void Visit(const char* key, uint64_t* value) final {
-    elements_.back().emplace_back(
-        llvm::ConstantInt::get(llvm_types_->t_int64, *value, false /* isSigned */));
-  }
-  void Visit(const char* key, int* value) final {
-    elements_.back().emplace_back(
-        llvm::ConstantInt::get(llvm_types_->t_int64, *value, true /* isSigned */));
-  }
-  void Visit(const char* key, bool* value) final {
-    elements_.back().emplace_back(llvm::ConstantInt::get(
-        llvm_types_->t_uint8, static_cast<uint64_t>(*value), false /* isSigned */));
-  }
-  void Visit(const char* key, std::string* value) final {
-    elements_.back().emplace_back(codegen_->GetConstString(*value));
-  }
-  void Visit(const char* key, void** value) final {
-    CHECK(false) << "Do not support serializing void*";
-  }
-  void Visit(const char* key, DataType* value) final {
-    elements_.back().emplace_back(llvm::ConstantStruct::get(
-        llvm_types_->t_data_type,
-        {llvm::ConstantInt::get(llvm_types_->t_uint8, value->code(), false /* isSigned */),
-         llvm::ConstantInt::get(llvm_types_->t_uint8, value->bits(), false /* isSigned */),
-         llvm::ConstantInt::get(llvm_types_->t_uint8, value->lanes(), false /* isSigned */)}));
-  }
-
-  // Serializing NDArray as tuple of len, data
-  void Visit(const char* key, runtime::NDArray* value) final {
-    std::string bytes;
-    dmlc::MemoryStringStream stream(&bytes);
-    value->Save(&stream);
-    elements_.back().emplace_back(
-        llvm::ConstantInt::get(llvm_types_->t_int64, bytes.length(), true /* isSigned */));
-    elements_.back().emplace_back(codegen_->GetConstString(bytes));
-  }
-
-  void VisitMetadata(runtime::metadata::MetadataBase metadata) {
-    elements_.emplace_back(std::vector<llvm::Constant*>());
-    ReflectionVTable::Global()->VisitAttrs(metadata.operator->(), this);
-    auto struct_elements = elements_.back();
-    elements_.pop_back();
-    auto struct_ty = llvm_types_->structs_by_type_key[metadata->GetTypeKey()];
-    ICHECK(struct_ty != nullptr) << "Did not find LLVM StructType* for type_key="
-                                 << metadata->GetTypeKey();
-    CHECK_EQ(struct_elements.size(), struct_ty->getNumElements());
-    auto out = llvm::ConstantStruct::get(struct_ty, struct_elements);
-    if (elements_.size() > 0) {
-      elements_.back().push_back(out);
-    } else {
-      last_production_ = out;
-    }
-  }
-
-  void VisitArray(const runtime::metadata::MetadataArrayNode* arr) {
-    llvm::Type* element_type;
-    switch (arr->kind) {
-      case MetadataKind::kInt64:
-        element_type = llvm_types_->t_int64;
-        break;
-      case MetadataKind::kUint64:
-        element_type = llvm_types_->t_int64;
-        break;
-      case MetadataKind::kBool:
-        element_type = llvm_types_->t_uint8;
-        break;
-      case MetadataKind::kString:
-        element_type = llvm_types_->t_cstring;
-        break;
-      case MetadataKind::kMetadata: {
-        element_type = llvm_types_->structs_by_type_key[arr->type_key];
-        ICHECK(element_type != nullptr)
-            << "Did not find LLVM StructType* for type_key=" << arr->type_key;
-        break;
-      }
-      default:
-        LOG(FATAL) << "unknown metadata kind " << arr->kind;
-        break;
-    }
-
-    elements_.emplace_back(std::vector<llvm::Constant*>());
-    for (auto o : arr->array) {
-      if (o->IsInstance<FloatImmNode>()) {
-        double value = Downcast<FloatImm>(o)->value;
-        Visit(nullptr, &value);
-      }
-      if (o->IsInstance<IntImmNode>()) {
-        auto value = Downcast<IntImm>(o)->value;
-        Visit(nullptr, &value);
-      } else if (o->IsInstance<StringObj>()) {
-        ::std::string value = Downcast<String>(o);
-        Visit(nullptr, &value);
-      } else {
-        // nested array not possible.
-        VisitMetadata(Downcast<runtime::metadata::MetadataBase>(o));
-      }
-    }
-    auto array = elements_.back();
-    elements_.pop_back();
-    CHECK(element_type != nullptr);
-    auto arr_ty = llvm::ArrayType::get(element_type, array.size());
-    auto llvm_arr = llvm::ConstantArray::get(arr_ty, array);
-
-    if (elements_.size() > 0) {
-      elements_.back().emplace_back(
-          codegen_->GetGlobalConstant(llvm_arr, "", llvm::GlobalValue::PrivateLinkage));
-    } else {
-      last_production_ = llvm_arr;
-    }
-  }
-
-  void Visit(const char* key, ObjectRef* value) final {
-    const runtime::metadata::MetadataArrayNode* arr =
-        value->as<runtime::metadata::MetadataArrayNode>();
-    if (arr != nullptr) {
-      VisitArray(arr);
-      return;
-    }
-
-    runtime::metadata::MetadataBase metadata = Downcast<runtime::metadata::MetadataBase>(*value);
-    VisitMetadata(metadata);
-  }
-
-  llvm::Constant* Serialize(runtime::metadata::MetadataBase metadata) {
-    Visit(nullptr, &metadata);
-    ICHECK(last_production_);
-    return codegen_->GetGlobalConstant(last_production_);
-  }
-
-  CodeGenLLVM* codegen_;
-  MetadataLlvmTypes* llvm_types_;
-  llvm::LLVMContext* ctx_;
-  llvm::Module* module_;
-  std::vector<std::vector<llvm::Constant*>> elements_;
-  llvm::Constant* last_production_;
-};
-
-void CodeGenCPU::DefineMetadata(runtime::metadata::Metadata metadata) {
-  llvm::LLVMContext* ctx = llvm_target_->GetContext();
-  MetadataLlvmTypes llvm_types{
-      t_float64_ /* t_float64 */,
-      llvm::Type::getInt8Ty(*ctx) /* t_uint8 */,
-      t_int64_ /* t_int64 */,
-      llvm::Type::getInt8Ty(*ctx) /* t_bool */,
-      llvmGetPointerTo(t_char_, 0) /* t_cstring */,
-      t_void_p_ /* t_void_p */,
-      llvm::StructType::create(*ctx, {t_int8_, t_int8_, t_int8_}, "DLDataType") /* t_data_type */,
-  };
-
-  // create sample ConstantInfoMetadata instance for MetadataTypeDefiner
-  std::string bytes;
-  runtime::NDArray ci = runtime::NDArray::Empty({0}, DataType::UInt(8), Device{kDLCPU});
-  dmlc::MemoryStringStream stream(&bytes);
-  ci.Save(&stream);
-  TVMConstantInfo di =
-      TVMConstantInfo{"default-none", 0, static_cast<int64_t>(bytes.size()), bytes.c_str()};
-
-  std::vector<runtime::metadata::MetadataBase> queue;
-  queue.push_back(runtime::metadata::ConstantInfoMetadata(&di));
-
-  metadata::DiscoverComplexTypesVisitor discover_complex{&queue};
-  discover_complex.Discover(metadata);
-
-  MetadataTypeDefiner definer{ctx, &llvm_types};
-  for (auto md : queue) {
-    if (md.defined()) {
-      definer.DefineType(md);
-    }
-  }
-
-  MetadataSerializerLLVM serializer{this, &llvm_types};
-  auto metadata_constant_gv = serializer.Serialize(metadata);
-
-  function_ =
-      llvm::Function::Create(ftype_tvm_backend_packed_c_func_, llvm::Function::ExternalLinkage,
-                             runtime::symbol::tvm_get_c_metadata, module_.get());
-  SetTargetAttributes(function_);
-  function_->setCallingConv(llvm::CallingConv::C);
-  function_->setDLLStorageClass(llvm::GlobalValue::DLLStorageClassTypes::DLLExportStorageClass);
-
-  llvm::BasicBlock* entry_point_entry = llvm::BasicBlock::Create(*ctx, "entry", function_);
-  builder_->SetInsertPoint(entry_point_entry);
-
-  auto ret_values_p = builder_->CreateBitCast(GetArg(function_, 3), llvmGetPointerTo(t_void_p_, 0));
-  builder_->CreateStore(builder_->CreateBitCast(metadata_constant_gv, t_void_p_), ret_values_p);
-
-  auto ret_tcode = builder_->CreateBitCast(GetArg(function_, 4), llvmGetPointerTo(t_int_, 0));
-  builder_->CreateStore(llvm::ConstantInt::get(t_int_, kTVMOpaqueHandle), ret_tcode);
-
-  builder_->CreateRet(ConstInt32(0));
-}
-
-void CodeGenCPU::DefineFunctionRegistry(Array<String> func_names) {
-  ICHECK(system_lib_prefix_.defined())
-      << "Loading of --system-lib modules is yet to be defined for C runtime";
-  Array<String> symbols;
-  std::vector<llvm::Constant*> funcs;
-  for (auto sym : func_names) {
-    symbols.push_back(sym);
-    auto* sym_func =
-        llvm::Function::Create(ftype_tvm_backend_packed_c_func_, llvm::GlobalValue::ExternalLinkage,
-                               sym.operator std::string(), module_.get());
-
-    funcs.emplace_back(sym_func);
-  }
-  llvm::ArrayType* t_tvm_crt_func_ptrs =
-      llvm::ArrayType::get(llvmGetPointerTo(ftype_tvm_backend_packed_c_func_, 0), funcs.size());
-#if TVM_LLVM_VERSION >= 200
-  llvm::DataLayout layout(module_.get()->getDataLayout());
-#else
-  llvm::DataLayout layout(module_.get());
-#endif
-
-  llvm::GlobalVariable* func_registry_ptrs = new llvm::GlobalVariable(
-      *module_, t_tvm_crt_func_ptrs, true, llvm::GlobalValue::InternalLinkage,
-      llvm::ConstantArray::get(t_tvm_crt_func_ptrs, funcs), "_tvm_func_registry_ptrs");
-
-  uint64_t align = layout.getTypeAllocSize(llvmGetPointerTo(ftype_tvm_backend_packed_c_func_, 0));
-#if TVM_LLVM_VERSION >= 100
-  func_registry_ptrs->setAlignment(llvm::Align(align));
-#else
-  func_registry_ptrs->setAlignment(align);
-#endif
-  llvm::GlobalVariable* func_registry = new llvm::GlobalVariable(
-      *module_, t_tvm_crt_func_registry_, true, llvm::GlobalVariable::InternalLinkage,
-      llvm::ConstantStruct::get(
-          t_tvm_crt_func_registry_,
-          {GetConstString(::tvm::target::GenerateFuncRegistryNames(symbols)),
-           llvm::ConstantExpr::getBitCast(func_registry_ptrs,
-                                          llvmGetPointerTo(ftype_tvm_backend_packed_c_func_, 0))}),
-      "_tvm_crt_func_registry");
-  llvm::GlobalVariable* module = new llvm::GlobalVariable(
-      *module_, t_tvm_crt_module_, true, llvm::GlobalValue::InternalLinkage,
-      llvm::ConstantStruct::get(t_tvm_crt_module_, {func_registry}), "_tvm_crt_module");
-
-  // Now build TVMSystemLibEntryPoint.
-  llvm::FunctionType* ftype = llvm::FunctionType::get(t_void_p_, {}, false);
-  function_ = llvm::Function::Create(ftype, llvm::Function::ExternalLinkage,
-                                     "TVMSystemLibEntryPoint", module_.get());
-  SetTargetAttributes(function_);
-  llvm::BasicBlock* entry_point_entry =
-      llvm::BasicBlock::Create(*llvm_target_->GetContext(), "entry", function_);
-  builder_->SetInsertPoint(entry_point_entry);
-  builder_->CreateRet(builder_->CreateBitCast(module, t_void_p_));
-}
-
 void CodeGenCPU::AddStartupFunction() {
   if (!target_c_runtime_) {
     llvm::FunctionType* ftype = llvm::FunctionType::get(t_void_, {}, false);
