@@ -23,8 +23,6 @@
  */
 #ifdef TVM_LLVM_VERSION
 
-#include "llvm_module.h"
-
 #include <dmlc/io.h>
 #include <llvm/ADT/SmallString.h>
 #include <llvm/ADT/StringRef.h>
@@ -56,11 +54,9 @@
 #include <llvm/Target/TargetOptions.h>
 #include <llvm/Transforms/Utils/Cloning.h>
 #include <tvm/ir/module.h>
-#include <tvm/relay/runtime.h>
 #include <tvm/runtime/container/array.h>
 #include <tvm/runtime/container/string.h>
 #include <tvm/runtime/logging.h>
-#include <tvm/runtime/metadata.h>
 #include <tvm/runtime/module.h>
 #include <tvm/runtime/object.h>
 #include <tvm/runtime/packed_func.h>
@@ -80,7 +76,6 @@
 
 #include "../../runtime/file_utils.h"
 #include "../../runtime/library_module.h"
-#include "../func_registry_generator.h"
 #include "codegen_blob.h"
 #include "codegen_cpu.h"
 #include "codegen_llvm.h"
@@ -328,19 +323,11 @@ void LLVMModuleNode::Init(const IRModule& mod, const Target& target) {
   std::unique_ptr<CodeGenLLVM> cg = CodeGenLLVM::Create(llvm_target.get());
 
   std::string entry_func;
-  relay::Runtime runtime =
-      mod->GetAttr<relay::Runtime>(tvm::attr::kRuntime).value_or(relay::Runtime::Create("cpp"));
 
   Optional<String> system_lib_prefix = mod->GetAttr<String>(tvm::attr::kSystemLibPrefix);
-  if (!system_lib_prefix && runtime->GetAttr<Bool>("system-lib").value_or(Bool(false))) {
-    system_lib_prefix = "";
-  }
-
-  bool target_c_runtime = runtime->name == "crt";
 
   for (auto kv : mod->functions) {
     if (!kv.second->IsInstance<PrimFuncNode>()) {
-      // (@jroesch): we relax constraints here, Relay functions will just be ignored.
       DLOG(INFO) << "Can only lower IR Module with PrimFuncs, but got " << kv.second->GetTypeKey();
       continue;
     }
@@ -361,8 +348,7 @@ void LLVMModuleNode::Init(const IRModule& mod, const Target& target) {
   // ICHECK(funcs.size() > 0);
   // TODO(tqchen): remove the entry function behavior as it does not
   // makes sense when we start to use multiple modules.
-  cg->Init("TVMMod", llvm_target.get(), system_lib_prefix, system_lib_prefix.defined(),
-           target_c_runtime);
+  cg->Init("TVMMod", llvm_target.get(), system_lib_prefix, system_lib_prefix.defined(), false);
   cg->SetFastMathFlags(llvm_target->GetFastMathFlags());
 
   cg->AddFunctionsOrdered(mod->functions.begin(), mod->functions.end());
@@ -690,6 +676,19 @@ TVM_REGISTER_GLOBAL("target.llvm_get_system_x86_vendor").set_body_typed([]() ->
   return "unimplemented";
 });
 
+TVM_REGISTER_GLOBAL("target.llvm_get_vector_width").set_body_typed([](const Target& target) -> int {
+  auto use_target = target.defined() ? target : Target::Current(false);
+  // ignore non "llvm" target
+  if (target.defined()) {
+    if (target->kind->name != "llvm") {
+      return -1;
+    }
+  }
+  auto llvm_instance = std::make_unique<LLVMInstance>();
+  LLVMTargetInfo llvm_backend(*llvm_instance, use_target);
+  return llvm_backend.GetVectorWidth();
+});
+
 TVM_REGISTER_GLOBAL("target.llvm_get_system_triple").set_body_typed([]() -> String {
   return llvm::sys::getDefaultTargetTriple();
 });
@@ -795,89 +794,6 @@ TVM_REGISTER_GLOBAL("codegen.codegen_blob")
       return runtime::Module(n);
     });
 
-runtime::Module CreateLLVMCppMetadataModule(runtime::metadata::Metadata metadata, Target target,
-                                            tvm::relay::Runtime runtime) {
-  auto llvm_instance = std::make_unique<LLVMInstance>();
-  With<LLVMTarget> llvm_target(*llvm_instance, target);
-
-  Optional<String> system_lib_prefix = NullOpt;
-  if (runtime->GetAttr<Bool>("system-lib").value_or(Bool(false))) {
-    system_lib_prefix = "";
-  }
-
-  auto cg = std::make_unique<CodeGenCPU>();
-
-  cg->Init("TVMMetadataMod", llvm_target.get(), system_lib_prefix, system_lib_prefix.defined(),
-           /*target_c_runtime=*/false);
-
-  cg->DefineMetadata(metadata);
-  auto mod = cg->Finish();
-  llvm_target->SetTargetMetadata(mod.get());
-  mod->addModuleFlag(llvm::Module::Override, "Debug Info Version", llvm::DEBUG_METADATA_VERSION);
-
-  mod->addModuleFlag(
-      llvm::Module::Override, "Dwarf Version",
-      llvm_target->GetOrCreateTargetMachine()->getTargetTriple().isOSDarwin() ? 2 : 4);
-
-  auto n = make_object<LLVMModuleNode>();
-  n->Init(std::move(mod), std::move(llvm_instance));
-  n->SetJITEngine(llvm_target->GetJITEngine());
-
-  auto meta_mod = MetadataModuleCreate(metadata);
-  meta_mod->Import(runtime::Module(n));
-  return meta_mod;
-}
-
-runtime::Module CreateLLVMCrtMetadataModule(const Array<runtime::Module>& modules, Target target,
-                                            tvm::relay::Runtime runtime) {
-  Array<String> func_names;
-  for (runtime::Module mod : modules) {
-    auto pf_funcs = mod.GetFunction("get_func_names");
-    if (pf_funcs != nullptr) {
-      Array<String> func_names_ = pf_funcs();
-      for (const auto& fname : func_names_) {
-        func_names.push_back(fname);
-      }
-    }
-  }
-
-  auto llvm_instance = std::make_unique<LLVMInstance>();
-  With<LLVMTarget> llvm_target(*llvm_instance, target);
-
-  Optional<String> system_lib_prefix = NullOpt;
-  if (runtime->GetAttr<Bool>("system-lib").value_or(Bool(false))) {
-    system_lib_prefix = "";
-  }
-
-  bool target_c_runtime = runtime->name == "crt";
-  ICHECK(system_lib_prefix.defined() && target_c_runtime)
-      << "For LLVM C-runtime metadata module, must include --system-lib and --runtime=c; "
-      << "got target: " << target->str();
-  auto cg = std::make_unique<CodeGenCPU>();
-  cg->Init("TVMMetadataMod", llvm_target.operator->(), system_lib_prefix,
-           system_lib_prefix.defined(), target_c_runtime);
-
-  cg->DefineFunctionRegistry(func_names);
-  auto mod = cg->Finish();
-  llvm_target->SetTargetMetadata(mod.get());
-  mod->addModuleFlag(llvm::Module::Override, "Debug Info Version", llvm::DEBUG_METADATA_VERSION);
-
-  mod->addModuleFlag(
-      llvm::Module::Override, "Dwarf Version",
-      llvm_target->GetOrCreateTargetMachine()->getTargetTriple().isOSDarwin() ? 2 : 4);
-
-  auto n = make_object<LLVMModuleNode>();
-  n->Init(std::move(mod), std::move(llvm_instance));
-  n->SetJITEngine(llvm_target->GetJITEngine());
-  for (auto m : modules) {
-    n->Import(m);
-  }
-  return runtime::Module(n);
-}
-
-TVM_REGISTER_GLOBAL("runtime.CreateLLVMCrtMetadataModule")
-    .set_body_typed(CreateLLVMCrtMetadataModule);
-
 }  // namespace codegen
 }  // namespace tvm
 
