@@ -26,10 +26,11 @@
 namespace tvm {
 namespace runtime {
 
-Module MetalModuleCreate(std::string data, std::string fmt,
-                         std::unordered_map<std::string, FunctionInfo> fmap, std::string source) {
+Module MetalModuleCreate(std::unordered_map<std::string, std::string> smap,
+                         std::unordered_map<std::string, FunctionInfo> fmap, std::string fmt,
+                         std::string source) {
   LOG(WARNING) << "Metal runtime not enabled, return a source module...";
-  return codegen::DeviceSourceModuleCreate(data, fmt, fmap, "metal");
+  return codegen::DeviceSourceModuleCreate(source, fmt, fmap, "metal");
 }
 
 }  // namespace runtime
