@@ -26,7 +26,6 @@
 #define TVM_TARGET_SOURCE_CODEGEN_SOURCE_BASE_H_
 
 #include <tvm/ir/name_supply.h>
-#include <tvm/runtime/metadata.h>
 #include <tvm/target/codegen.h>
 #include <tvm/tir/expr.h>
 #include <tvm/tir/op.h>
@@ -162,12 +161,11 @@ runtime::Module CSourceModuleCreate(const String& code, const String& fmt,
  * \param target_module The main TIR-lowered internal runtime module
  * \param modules All the external modules that needs to be imported inside the metadata module(s).
  * \param target The target that all the modules are compiled for
- * \param metadata Metadata which should be exported to the runtime.
  * \return The wrapped module.
  */
 runtime::Module CreateMetadataModule(
     const std::unordered_map<std::string, runtime::NDArray>& params, runtime::Module target_module,
-    const Array<runtime::Module>& ext_modules, Target target, runtime::metadata::Metadata metadata);
+    const Array<runtime::Module>& ext_modules, Target target);
 
 /*!
  * \brief Create a source module for viewing and limited saving for device.
@@ -181,16 +179,6 @@ runtime::Module DeviceSourceModuleCreate(
     std::string data, std::string fmt, std::unordered_map<std::string, runtime::FunctionInfo> fmap,
     std::string type_key, std::function<std::string(const std::string&)> fget_source = nullptr);
 
-/*!
- * \brief Wrap the submodules that are to be wrapped in a c-source metadata module for C runtime.
- * \param modules The modules to be wrapped.
- * \param target the target the modules are compiled for.
- * \param metadata the metadata needed for code generation.
- * \return The wrapped module.
- */
-runtime::Module CreateCSourceCrtMetadataModule(const Array<runtime::Module>& modules, Target target,
-                                               runtime::metadata::Metadata metadata);
-
 }  // namespace codegen
 }  // namespace tvm
 #endif  // TVM_TARGET_SOURCE_CODEGEN_SOURCE_BASE_H_
