@@ -38,8 +38,6 @@ TVM_REGISTER_NODE_TYPE(PlaceholderOpNode);
 
 int PlaceholderOpNode::num_outputs() const { return 1; }
 
-Array<IterVar> PlaceholderOpNode::root_iter_vars() const { return {}; }
-
 DataType PlaceholderOpNode::output_dtype(size_t i) const {
   ICHECK_EQ(i, 0U);
   return dtype;
@@ -79,30 +77,5 @@ TVM_REGISTER_GLOBAL("te.Placeholder")
 
 Array<Tensor> PlaceholderOpNode::InputTensors() const { return {}; }
 
-Operation PlaceholderOpNode::ReplaceInputs(const Operation& self,
-                                           const std::unordered_map<Tensor, Tensor>& rmap) const {
-  return self;
-}
-
-void PlaceholderOpNode::PropBoundToInputs(
-    const Operation& self, arith::Analyzer* analyzer,
-    const std::unordered_map<const VarNode*, IntSet>& dom_map,
-    std::unordered_map<Tensor, TensorDom>* out_dom_map) const {}
-
-void PlaceholderOpNode::GatherBound(const Operation& self,
-                                    const std::unordered_map<Tensor, TensorDom>& tensor_dom,
-                                    std::unordered_map<IterVar, Range>* out_dom_map) const {}
-
-Stmt PlaceholderOpNode::BuildRealize(const Stage& stage,
-                                     const std::unordered_map<IterVar, Range>& realize_map,
-                                     const Stmt& body, String storage_scope) const {
-  return body;
-}
-
-Stmt PlaceholderOpNode::BuildProvide(const Stage& stage,
-                                     const std::unordered_map<IterVar, Range>& dom_map,
-                                     bool debug_keep_trivial_loop) const {
-  return Stmt();
-}
 }  // namespace te
 }  // namespace tvm
