@@ -920,14 +920,9 @@ class CrossThreadReductionTransformer : public StmtMutator {
 };
 
 PrimFunc LowerCrossThreadReduction(PrimFunc f) {
-  // Only apply this pass to TIR that is not from TE schedules
-  if (!IsFromLegacyTESchedule(f)) {
-    PrimFuncNode* fptr = f.CopyOnWrite();
-    fptr->body = CrossThreadReductionTransformer()(f->body);
-    return f;
-  } else {
-    return f;
-  }
+  PrimFuncNode* fptr = f.CopyOnWrite();
+  fptr->body = CrossThreadReductionTransformer()(f->body);
+  return f;
 }
 
 namespace transform {
