@@ -169,7 +169,7 @@ class MmaBufferLayoutTransformer : public StmtExprMutator {
 
  private:
   std::unordered_map<Buffer, Buffer, ObjectPtrHash, ObjectPtrEqual> buffer_map_;
-  std::unordered_map<Var, Var, ObjectPtrHash, ObjectPtrEqual> buffer_var_map_;
+  std::unordered_map<Var, Var> buffer_var_map_;
   arith::Analyzer analyzer;
 };
 
