@@ -1,4 +1,4 @@
-#!/bin/bash -e
+#!/usr/bin/env bash
 # Licensed to the Apache Software Foundation (ASF) under one
 # or more contributor license agreements.  See the NOTICE file
 # distributed with this work for additional information
@@ -16,5 +16,6 @@
 # specific language governing permissions and limitations
 # under the License.
 
+set -e
 
 python3 3rdparty/dmlc-core/scripts/lint.py tvm4j-jni cpp jvm/native/src
