@@ -15,10 +15,14 @@
 # specific language governing permissions and limitations
 # under the License.
 """Test packed function FFI."""
+import gc
+
+import numpy as np
+
 import tvm
 from tvm import te
 import tvm.testing
-import numpy as np
+from tvm.script import tir as T
 
 
 def test_get_global():
@@ -37,7 +41,7 @@ def test_get_global():
 
 
 def test_get_callback_with_node():
-    x = tvm.runtime.convert(10)
+    x = T.int32(10)
 
     def test(y):
         assert y.handle != x.handle
@@ -66,7 +70,7 @@ def test_return_func():
 
     myf = tvm.runtime.convert(addy)
     f = myf(10)
-    assert f(11).value == 21
+    assert f(11) == 21
 
 
 def test_convert():
@@ -113,6 +117,14 @@ def test_device():
 
 def test_rvalue_ref():
     def callback(x, expected_count):
+        # The use count of TVM objects is decremented as part of
+        # `ObjectRef.__del__`, which runs when the Python object is
+        # destructed.  However, Python object destruction is not
+        # deterministic, and even CPython's reference-counting is
+        # considered an implementation detail.  Therefore, to ensure
+        # correct results from this test, `gc.collect()` must be
+        # explicitly called.
+        gc.collect()
         assert expected_count == tvm.testing.object_use_count(x)
         return x
 
