@@ -26,7 +26,7 @@ import pytest
 
 import tvm
 import tvm.testing
-from tvm import relay, te
+from tvm import te, tir
 from tvm.topi.math import cast
 from tvm.script import tir as T, ir as I
 from tvm.tir import TensorIntrin, IntImm, Cast, Schedule
@@ -60,9 +60,10 @@ fuzz_seed = tvm.testing.parameter(range(25))
         ]
     )
 )
-def test_vector_comparison(target, dtype):
-    n = (1024,)
-    A = te.placeholder(n, dtype=dtype, name="A")
+def test_vector_comparison(target, dev, dtype):
+    target = tvm.target.Target(target)
+    n = 1024
+    A = te.placeholder((n,), dtype=dtype, name="A")
     B = te.compute(
         A.shape,
         lambda i: tvm.tir.Select(
@@ -70,14 +71,18 @@ def test_vector_comparison(target, dtype):
         ),
         name="B",
     )
-    s = te.create_schedule(B.op)
 
-    (bx, tx) = s[B].split(s[B].op.axis[0], factor=128)
-    (tx, vx) = s[B].split(tx, factor=4)
-    s[B].bind(bx, te.thread_axis("blockIdx.x"))
-    s[B].bind(tx, te.thread_axis("threadIdx.x"))
-    s[B].vectorize(vx)
-    f = tvm.build(s, [A, B], target)
+    # Create IRModule
+    mod = tvm.IRModule.from_expr(te.create_prim_func([A, B]))
+    sch = tir.Schedule(mod)
+    (bx, tx) = sch.split(sch.get_loops("B")[0], factors=[None, 128])
+    (tx, vx) = sch.split(tx, factors=[None, 4])
+    sch.bind(bx, "blockIdx.x")
+    sch.bind(tx, "threadIdx.x")
+    sch.vectorize(vx)
+
+    # Build
+    f = tvm.tir.build(sch.mod, target=target)
 
     # Verify we generate the boolx4 type declaration and the OpSelect
     # v4{float,half,int} instruction
@@ -102,193 +107,56 @@ def test_array_copy(dev, dtype, fuzz_seed):
 
 @tvm.testing.exclude_targets("llvm")
 def test_array_vectorize_add(target, dev, dtype):
+    target = tvm.target.Target(target)
     arr_size = 64
     lanes = 2
-    if "opencl" in target and dtype == "float16":
+
+    if "opencl" in str(target) and dtype == "float16":
         pytest.xfail("Opencl target does not support float16")
 
-    num_thread = 8
-
     A = te.placeholder((arr_size,), name="A", dtype="%sx%d" % (dtype, lanes))
-    B = te.compute((arr_size,), lambda i: A[i] + tvm.tir.const(1, A.dtype), name="B")
-    s = te.create_schedule(B.op)
-    xo, xi = s[B].split(B.op.axis[0], factor=num_thread)
-    s[B].bind(xo, te.thread_axis("blockIdx.x"))
-    s[B].bind(xi, te.thread_axis("threadIdx.x"))
-    fun = tvm.build(s, [A, B], target)
+    B = te.compute(A.shape, lambda i: A[i] + tvm.tir.const(1, A.dtype), name="B")
+
+    sch = tir.Schedule(te.create_prim_func([A, B]))
+    xo, xi = sch.split(sch.get_loops("B")[0], factors=[None, 4])
+    sch.bind(xo, "blockIdx.x")
+    sch.bind(xi, "threadIdx.x")
+    f = tvm.compile(sch.mod, target=target)
+
     a = tvm.nd.empty((arr_size,), A.dtype, dev).copyfrom(np.random.uniform(size=(arr_size, lanes)))
     c = tvm.nd.empty((arr_size,), B.dtype, dev)
-    fun(a, c)
+    f(a, c)
     tvm.testing.assert_allclose(c.numpy(), a.numpy() + 1)
 
 
-@tvm.testing.parametrize_targets("vulkan")
-@pytest.mark.skip("Flaky, https://github.com/apache/tvm/issues/10779")
-def test_vulkan_stress(target, dev):
-    """
-    Launch a randomized test with multiple kernels per stream, multiple uses of
-    kernels per stream, over multiple threads.
-    """
-
-    n = 1024
-    num_thread = 64
-
-    def run_stress():
-        def worker():
-            A = te.placeholder((n,), name="A", dtype="float32")
-            B = te.placeholder((n,), name="B", dtype="float32")
-            functions = [
-                (
-                    lambda: te.compute((n,), lambda i: 2 * A[i] + 3 * B[i]),
-                    lambda a, b: 2 * a + 3 * b,
-                ),
-                (lambda: te.compute((n,), lambda i: A[i] + B[i]), lambda a, b: a + b),
-                (lambda: te.compute((n,), lambda i: A[i] + 2 * B[i]), lambda a, b: a + 2 * b),
-            ]
-
-            def build_f(f_ref):
-                (C_f, ref) = f_ref
-                C = C_f()
-                s = te.create_schedule(C.op)
-                xo, xi = s[C].split(C.op.axis[0], factor=num_thread)
-                s[C].bind(xo, te.thread_axis("blockIdx.x"))
-                s[C].bind(xi, te.thread_axis("threadIdx.x"))
-                fun = tvm.build(s, [A, B, C], target)
-                return (fun, ref)
-
-            fs = [
-                build_f(random.choice(functions)) for _ in range(np.random.randint(low=1, high=10))
-            ]
-            a = tvm.nd.empty((n,), A.dtype, dev).copyfrom(np.random.uniform(size=(n,)))
-            b = tvm.nd.empty((n,), B.dtype, dev).copyfrom(np.random.uniform(size=(n,)))
-            cs = [tvm.nd.empty((n,), A.dtype, dev) for _ in fs]
-            for ((f, _), c) in zip(fs, cs):
-                f(a, b, c)
-
-            for ((_, ref), c) in zip(fs, cs):
-                tvm.testing.assert_allclose(c.numpy(), ref(a.numpy(), b.numpy()))
-
-        ts = [threading.Thread(target=worker) for _ in range(np.random.randint(1, 10))]
-        for t in ts:
-            t.start()
-        for t in ts:
-            t.join()
-
-    run_stress()
-
-
 @tvm.testing.exclude_targets("llvm")
 def test_vulkan_bool_load(target, dev):
-    arr_size = 1024
-
     target = tvm.target.Target(target)
-    if target.kind.name == "vulkan":
-        supports_int8_buffer = target.attrs.get("supports_int8", False) and target.attrs.get(
-            "supports_8bit_buffer", False
-        )
-        if not supports_int8_buffer:
-            pytest.xfail(
-                "Vulkan target does not support int8 buffer access, used to transfer booleans"
-            )
-
-    def do_copy(A, B, n):
-        ib = tvm.tir.ir_builder.create()
-        A = ib.buffer_ptr(A)
-        B = ib.buffer_ptr(B)
-
-        tx = te.thread_axis("threadIdx.x")
-        bx = te.thread_axis("blockIdx.x")
-
-        max_threads = 32
-        ib.scope_attr(bx, "thread_extent", tvm.tir.indexdiv(n + max_threads - 1, max_threads))
-        ib.scope_attr(tx, "thread_extent", max_threads)
-        tid = bx * max_threads + tx
-
-        with ib.if_scope(tid < n):
-            B[tid] = cast(A[tid], "int32")
-
-        return ib.get()
-
+    arr_size = 1024
     A = te.placeholder((arr_size,), name="A", dtype="bool")
-    B = te.placeholder((arr_size,), name="B", dtype="int32")
+    B = te.compute(A.shape, lambda i: A[i].astype("int32"), name="B")
 
-    B = te.extern(
-        A.shape,
-        [A],
-        lambda ins, outs: do_copy(ins[0], outs[0], arr_size),
-        name="bool_copy_ir",
-        dtype="int32",
-    )
-    s = te.create_schedule(B.op)
+    sch = tir.Schedule(te.create_prim_func([A, B]))
+    xo, xi = sch.split(sch.get_loops("B")[0], factors=[None, 128])
+    sch.bind(xo, "blockIdx.x")
+    sch.bind(xi, "threadIdx.x")
 
-    with tvm.transform.PassContext(opt_level=3):
-        func = tvm.build(s, [A, B], target)
+    # Build
+    f = tvm.compile(sch.mod, target=target)
 
     a_np = np.random.uniform(size=arr_size) > 0.5
     b_np = np.zeros((arr_size,), dtype="int32")
     a = tvm.nd.array(a_np, dev)
     b = tvm.nd.array(b_np, dev)
-    func(a, b)
+    f(a, b)
     ref = a_np.astype(np.int32)
     tvm.testing.assert_allclose(b.numpy(), ref)
 
 
-def check_mod(target, dev, mod, x_np, res_np):
-    res = relay.create_executor("vm", mod=mod, device=dev, target=target).evaluate()(x_np).numpy()
-    tvm.testing.assert_allclose(res, res_np, atol=1e-5)
-
-
-def test_sqrt(target, dev):
-    # Three 32 bit pushconstants: any_dim, stride, stride
-    dtype = "float32"
-    x = relay.var("x", shape=(relay.Any(),), dtype=dtype)
-    mod = tvm.IRModule()
-    mod["main"] = relay.Function([x], relay.sqrt(x))
-    x_np = np.random.uniform(size=(10,)).astype(dtype)
-    res_np = np.sqrt(x_np)
-
-    check_mod(target, dev, mod, x_np, res_np)
-
-
-def test_argsort(target, dev):
-    # One 64 bit and one 32 bit constants
-    dtype = "int32"
-    x = relay.var("x", shape=(relay.Any(),), dtype=dtype)
-    mod = tvm.IRModule()
-    mod["main"] = relay.Function([x], relay.argsort(x))
-    x_np = np.random.randint(0, high=10, size=(10,)).astype(dtype)
-    res_np = np.argsort(x_np, kind="stable")
-
-    check_mod(target, dev, mod, x_np, res_np)
-
-
-def test_cumsum(target, dev):
-    # One 64 bit and one 32 bit constants
-    dtype = "int32"
-    x = relay.var("x", shape=(relay.Any(),), dtype=dtype)
-    mod = tvm.IRModule()
-    mod["main"] = relay.Function([x], relay.cumsum(x))
-    x_np = np.random.randint(0, high=10, size=(10,)).astype(dtype)
-    res_np = np.cumsum(x_np)
-
-    check_mod(target, dev, mod, x_np, res_np)
-
-
-@tvm.testing.skip_if_wheel_test
-def test_unique(target, dev):
-    dtype = "int32"
-    x = relay.var("x", shape=(relay.Any(),), dtype=dtype)
-    mod = tvm.IRModule()
-    [unique, _, _, num_unique] = relay.unique(x, is_sorted=True)
-    mod["main"] = relay.Function([x], relay.op.strided_slice(unique, begin=[0], end=num_unique))
-    x_np = np.random.randint(0, high=10, size=(10,)).astype(dtype)
-    res_np = np.unique(x_np)
-    check_mod(target, dev, mod, x_np, res_np)
-
-
 vulkan_parameter_impl = tvm.testing.parameter("push_constants", "ubo")
 vulkan_parameter_dtype = tvm.testing.parameter("int32", "float32", "int64")
 
+
 # Only run on vulkan because extremely large numbers of input
 # parameters can crash cuda/llvm compiler.
 @tvm.testing.parametrize_targets("vulkan -from_device=0")
@@ -322,11 +190,11 @@ def test_vulkan_constant_passing(target, dev, vulkan_parameter_impl, vulkan_para
     A = te.placeholder((n,), name="A", dtype=dtype)
     B = te.compute(A.shape, lambda i: scalar_sum + A[i], name="B")
 
-    s = te.create_schedule(B.op)
-    xo, xi = s[B].split(B.op.axis[0], factor=64)
-    s[B].bind(xo, te.thread_axis("blockIdx.x"))
-    s[B].bind(xi, te.thread_axis("threadIdx.x"))
-    f_add = tvm.build(s, scalars + [A, B], target)
+    sch = tvm.tir.Schedule(te.create_prim_func(scalars + [A, B]))
+    xo, xi = sch.split(sch.get_loops("B")[0], factors=[None, 64])
+    sch.bind(xo, "blockIdx.x")
+    sch.bind(xi, "threadIdx.x")
+    f_add = tvm.compile(sch.mod, target=target)
 
     n = 1024
     scalars = np.array([1 for _ in scalars]).astype(dtype)
@@ -339,6 +207,9 @@ def test_vulkan_constant_passing(target, dev, vulkan_parameter_impl, vulkan_para
 
 def test_vulkan_while_if(target, dev):
     target = tvm.target.Target(target)
+    n = 1
+    dtype = "int32"
+    A = te.placeholder((n,), name="A", dtype=dtype)
 
     def do_compute(A, B, n):
         ib = tvm.tir.ir_builder.create()
@@ -352,9 +223,6 @@ def test_vulkan_while_if(target, dev):
         iterations[0] = 0
         B[0] = 0
 
-        # WhileNode's condition is re-evaluated every loop.  The
-        # if_then_else block introduces additional labels/blocks that
-        # must be kept separate from the WhileNode's block.
         loop_condition = iterations[0] < tvm.tir.if_then_else(A[0] > 0, 10, 20)
         with ib.while_loop(loop_condition):
             iterations[0] += 1
@@ -362,21 +230,19 @@ def test_vulkan_while_if(target, dev):
 
         return ib.get()
 
-    n = 1
-    dtype = "int32"
-    A = te.placeholder((n,), name="A", dtype=dtype)
-
     B = te.extern(
         A.shape,
         [A],
         lambda ins, outs: do_compute(ins[0], outs[0], n),
         dtype=dtype,
     )
-    s = te.create_schedule(B.op)
 
-    # Point of failure would be here, at tvm.build.
-    with tvm.transform.PassContext(opt_level=3):
-        func = tvm.build(s, [A, B], target)
+    # Create IRModule
+    mod = tvm.IRModule.from_expr(te.create_prim_func([A, B]))
+    sch = tir.Schedule(mod)
+
+    # Build
+    func = tvm.compile(sch.mod, target=target)
 
     a = tvm.nd.array(np.array([5], dtype=A.dtype), dev)
     b = tvm.nd.array(np.zeros(n, dtype=A.dtype), dev)
@@ -391,52 +257,40 @@ def test_vulkan_while_if(target, dev):
 
 @tvm.testing.exclude_targets("llvm")
 def test_vulkan_local_threadidx(target, dev):
-    # To access the thread index, the vulkan runtime accesses a global
-    # array of thread indices, storing the result in a local variable.
-    # In CUDA, these are the built-in threadIdx.x variables, which are
-    # globally accessible.  In vulkan, these local variables must be
-    # defined inside a function, but are hoisted up to the function
-    # header to mimic the global CUDA semantics.  Before this
-    # hoisting, this test could trigger spvValidate errors for
-    # potentially undeclared variables.
+    target = tvm.target.Target(target)
+    n = 32
+    A = te.placeholder((n,), name="A", dtype="int32")
 
     def do_compute(A, B, n):
         ib = tvm.tir.ir_builder.create()
         A = ib.buffer_ptr(A)
         B = ib.buffer_ptr(B)
 
-        # One single declaration of te.thread_axis.
         tx = te.thread_axis("threadIdx.x")
 
         with ib.for_range(0, 1):
-            # Used inside a for-loop scope, defines local thread_id
-            # variable.
             ib.scope_attr(tx, "thread_extent", 16)
             B[tx + 0] = A[tx + 0]
 
         with ib.for_range(0, 1):
-            # Used in next scope.  If local variable defined at point
-            # of use instead of function header, will fail spvValidate
-            # for access of out-of-scope local variable.
             ib.scope_attr(tx, "thread_extent", 16)
             B[tx + 16] = A[tx + 16]
 
         return ib.get()
 
-    n = te.var("n")
-    A = te.placeholder((n,), name="A", dtype="int32")
-    B = te.placeholder((n,), name="B", dtype="int32")
-
     B = te.extern(
         A.shape,
         [A],
         lambda ins, outs: do_compute(ins[0], outs[0], n),
         dtype="int32",
     )
-    s = te.create_schedule(B.op)
 
-    # Expected failure occurs at build step.
-    func = tvm.build(s, [A, B], target)
+    # Create IRModule
+    mod = tvm.IRModule.from_expr(te.create_prim_func([A, B]))
+    sch = tir.Schedule(mod)
+
+    # Build
+    func = tvm.compile(sch.mod, target=target)
 
     n = 32
     a_np = np.arange(n).astype(dtype=A.dtype)
@@ -525,12 +379,11 @@ class TestVectorizedIndices:
             return ib.get()
 
         B = te.extern(A.shape, [A, R], do_compute, dtype="int32")
-        s = te.create_schedule(B.op)
 
-        return tvm.lower(s, [A, R, B])
+        return tvm.IRModule.from_expr(te.create_prim_func([A, R, B]))
 
     def test_ramp_broadcast_index(self, target, dev, mod, ref_data):
-        f = tvm.build(mod, target=target)
+        f = tvm.compile(mod, target=target)
 
         a_np, reorder_np, b_np = ref_data
         a = tvm.nd.array(a_np, dev)
@@ -540,36 +393,6 @@ class TestVectorizedIndices:
         tvm.testing.assert_allclose(b.numpy(), b_np)
 
 
-@tvm.testing.parametrize_targets("vulkan -max_shared_memory_per_block=16384")
-def test_shared_mem_alloc(target, dev):
-    alloc_nbytes = 16384 * 2
-
-    def do_compute(ins, outs):
-        ib = tvm.tir.ir_builder.create()
-        out = ib.buffer_ptr(outs[0])
-
-        ib.scope_attr(te.thread_axis("blockIdx.x"), "thread_extent", 0)
-
-        array = ib.allocate("int32", (alloc_nbytes,), name="array", scope="shared")
-        array[0] = 0
-        out[0] = array[0]
-
-        return ib.get()
-
-    Out = te.extern(
-        shape=(1,),
-        inputs=[],
-        fcompute=do_compute,
-        dtype="int32",
-    )
-    s = te.create_schedule(Out.op)
-
-    # Codegen should raise error when allocating more memory than the
-    # target supports.
-    with pytest.raises(tvm.TVMError):
-        tvm.build(s, [Out], target)
-
-
 def test_negative_operand_divmod(target, dev):
     """Test handling of negative offsets to floormod/floordiv
 
@@ -601,7 +424,7 @@ def test_negative_operand_divmod(target, dev):
         sch.bind(sch.get_loops("A")[0], "threadIdx.x")
         func = sch.mod["main"]
 
-    built = tvm.build(func, target=target)
+    built = tvm.compile(func, target=target)
 
     a_dev = tvm.nd.empty([N, 2], "int32", dev)
     built(a_dev)
@@ -711,7 +534,7 @@ def test_cooperative_matrix(out_dtype):
     tgt_attrs = tvm.target.Target(target).attrs
 
     if tgt_attrs.get("supports_cooperative_matrix"):
-        f = tvm.build(sch.mod, target=target)
+        f = tvm.compile(sch.mod, target=target)
 
         dev = tvm.device(target, 0)
 
