@@ -16,12 +16,11 @@
 # under the License.
 # pylint: disable=invalid-name
 
-""" Hexagon testing infrastructure """
+"""Hexagon testing infrastructure"""
 
 import numpy
 import tvm
 from tvm import te
-from tvm.relay.backend import Executor
 
 
 def ceildiv(o, d):
@@ -95,7 +94,7 @@ def build_and_run(inputs, func, target: str, target_host: str, *args, **kwargs):
     """build and run the function func"""
     schedule, placeholders, binds = func(*args, **kwargs)
 
-    func = tvm.build(
+    func = tvm.compile(
         schedule, placeholders, target=tvm.target.Target(target, host=target_host), binds=binds
     )
     dev = tvm.device(target)
@@ -113,19 +112,6 @@ def build_and_run(inputs, func, target: str, target_host: str, *args, **kwargs):
     return tensors[-1].asnumpy()
 
 
-def build_module(relay_mod, target):
-    """builds a relay module for a specified target"""
-    params = {}
-    executor = Executor("aot", {"link-params": True})
-    lowered = tvm.relay.build(
-        relay_mod,
-        tvm.target.Target(target, host=target),
-        executor=executor,
-        params=params,
-    )
-    return lowered
-
-
 def run_module(mod, inputs):
     """invokes run function of specified module with inputs provided"""
     mod.set_input(**inputs)
