@@ -64,7 +64,7 @@ pytestmark = [
 def build_and_run(mod, inputs_np, target, legalize=False):
     dev = tvm.device(target, 0)
     with tvm.transform.PassContext(config={"relax.transform.apply_legalize_ops": legalize}):
-        ex = relax.build(mod, target)
+        ex = tvm.compile(mod, target)
     vm = relax.VirtualMachine(ex, dev)
     f = vm["main"]
     inputs = [tvm.nd.array(inp, dev) for inp in inputs_np]
