@@ -15,17 +15,21 @@
 # specific language governing permissions and limitations
 # under the License.
 
-import pytest
 import os
+import tempfile
+
+import numpy as np
+import pytest
+
 import tvm
 import tvm.testing
 from tvm import relax, tir
-import numpy as np
-from tvm.script import relax as R, ir as I, tir as T
-from tvm.relax.testing import transform
-import tempfile
-from tvm.relax.transform.tuning_api import Trace
 from tvm.relax.dpl import is_op, wildcard
+from tvm.relax.testing import transform
+from tvm.relax.transform.tuning_api import Trace
+from tvm.script import ir as I
+from tvm.script import relax as R
+from tvm.script import tir as T
 
 env_checker_codegen = tvm.get_global_func("relax.ext.tensorrt", True)
 env_checker_runtime = tvm.get_global_func("relax.is_tensorrt_runtime_enabled", True)
@@ -74,7 +78,7 @@ def gen_ground_truth(mod, target, dev, inputs):
         )
         new_mod = seq(mod)
     assert relax.analysis.well_formed(new_mod)
-    exec = relax.build(new_mod, target, params={})
+    exec = tvm.compile(new_mod, target, params={})
     vm = relax.VirtualMachine(exec, dev)
     return vm["main"](*inputs)
 
@@ -141,7 +145,7 @@ def test_tensorrt_only(entry_func_name):
         ]
     )(mod)
 
-    ex0 = relax.build(new_mod, target, params={})
+    ex0 = tvm.compile(new_mod, target, params={})
     # Sanity check for the correctness and roundtrip
     check_roundtrip(ex0, dev, inputs, expected, entry_func_name)
 
@@ -175,7 +179,7 @@ def test_mix_use_tensorrt_and_tvm():
             )(mod)
     assert relax.analysis.well_formed(new_mod)
     with transform.PassContext(opt_level=0):
-        ex0 = relax.build(new_mod, target, params={})
+        ex0 = tvm.compile(new_mod, target, params={})
 
     # Sanity check for the correctness and roundtrip
     check_roundtrip(ex0, dev, inputs, expected)
@@ -280,7 +284,7 @@ def test_default_entry_func():
 
 
 def test_dynamic_shape():
-    import tvm.relax.backend.contrib.cublas
+    import tvm.relax.backend.cuda.cublas
 
     @I.ir_module
     class Before:
