@@ -21,7 +21,6 @@ import sys
 import numpy as np
 import subprocess
 import tvm.testing
-from tvm.relay.backend import Runtime
 import pytest
 
 runtime_py = """
@@ -29,7 +28,6 @@ import os
 import sys
 
 os.environ["TVM_USE_RUNTIME_LIB"] = "1"
-os.environ["TVM_FFI"] = "ctypes"
 import tvm
 from tvm import te
 import numpy as np
@@ -64,7 +62,7 @@ def test_dso_module_load(target):
         mod = tvm.IRModule.from_expr(
             tvm.tir.PrimFunc([Ab], stmt).with_attr("global_symbol", "main")
         )
-        m = tvm.driver.build(mod, target=target)
+        m = tvm.tir.build(mod, target=target)
         for name in names:
             m.save(name)
 
@@ -102,12 +100,13 @@ def test_device_module_dump():
     n = tvm.runtime.convert(1024)
     A = te.placeholder((n,), name="A")
     B = te.compute(A.shape, lambda *i: A(*i) + 1.0, name="B")
-    s = te.create_schedule(B.op)
+
+    sch = tvm.tir.Schedule(te.create_prim_func([A, B]))
     # create iter var and assign them tags.
     num_thread = 8
-    bx, tx = s[B].split(B.op.axis[0], factor=num_thread)
-    s[B].bind(bx, te.thread_axis("blockIdx.x"))
-    s[B].bind(tx, te.thread_axis("threadIdx.x"))
+    bx, tx = sch.split(sch.get_loops("B")[0], factors=[None, num_thread])
+    sch.bind(bx, "blockIdx.x")
+    sch.bind(tx, "threadIdx.x")
 
     def check_device(device):
         dev = tvm.device(device, 0)
@@ -115,14 +114,7 @@ def test_device_module_dump():
             print("Skip because %s is not enabled" % device)
             return
         temp = utils.tempdir()
-        name = "myadd_%s" % device
-        if sys.platform == "darwin" or sys.platform.startswith("linux"):
-            runtime = Runtime("cpp", {"system-lib": True})
-            f = tvm.build(s, [A, B], device, "llvm", runtime=runtime, name=name)
-        elif sys.platform == "win32":
-            f = tvm.build(s, [A, B], device, "llvm", name=name)
-        else:
-            raise ValueError("Unsupported platform")
+        f = tvm.compile(sch.mod, target=device)
 
         path_dso = temp.relpath("dev_lib.so")
         # test cross compiler function
@@ -130,42 +122,32 @@ def test_device_module_dump():
 
         def popen_check():
             import tvm
-            import sys
 
             f1 = tvm.runtime.load_module(path_dso)
             a = tvm.nd.array(np.random.uniform(size=1024).astype(A.dtype), dev)
             b = tvm.nd.array(np.zeros(1024, dtype=A.dtype), dev)
             f1(a, b)
             np.testing.assert_equal(b.numpy(), a.numpy() + 1)
-            if sys.platform != "win32":
-                f2 = tvm.runtime.system_lib()
-                f2[name](a, b)
-                np.testing.assert_equal(b.numpy(), a.numpy() + 1)
 
         # system lib should be loaded in different process
         worker = popen_pool.PopenWorker()
         worker.send(popen_check)
         worker.recv()
 
-    def check_stackvm(device):
+    def check_c(device):
         dev = tvm.device(device, 0)
         if not tvm.testing.device_enabled(device):
             print("Skip because %s is not enabled" % device)
             return
-        temp = utils.tempdir()
-        name = "myadd_%s" % device
-        f = tvm.build(s, [A, B], device, "stackvm", name=name)
-        path_dso = temp.relpath("dev_lib.stackvm")
-        f.export_library(path_dso)
-        f1 = tvm.runtime.load_module(path_dso)
+        f = tvm.compile(sch.mod, target=tvm.target.Target(device, host="c"))
         a = tvm.nd.array(np.random.uniform(size=1024).astype(A.dtype), dev)
         b = tvm.nd.array(np.zeros(1024, dtype=A.dtype), dev)
-        f(a, b)
+        f["main"](a, b)
         np.testing.assert_equal(b.numpy(), a.numpy() + 1)
 
     for device in ["cuda", "vulkan", "opencl", "metal"]:
         check_device(device)
-        check_stackvm(device)
+        check_c(device)
 
 
 @tvm.testing.requires_llvm
@@ -176,13 +158,14 @@ def test_combine_module_llvm():
     n = tvm.runtime.convert(nn)
     A = te.placeholder((n,), name="A")
     B = te.compute(A.shape, lambda *i: A(*i) + 1.0, name="B")
-    s = te.create_schedule(B.op)
+    mod1 = tvm.IRModule.from_expr(te.create_prim_func([A, B]).with_attr("global_symbol", "myadd1"))
+    mod2 = tvm.IRModule.from_expr(te.create_prim_func([A, B]).with_attr("global_symbol", "myadd2"))
 
     def check_llvm():
         dev = tvm.cpu(0)
         temp = utils.tempdir()
-        fadd1 = tvm.build(s, [A, B], "llvm", name="myadd1")
-        fadd2 = tvm.build(s, [A, B], "llvm", name="myadd2")
+        fadd1 = tvm.tir.build(mod1, "llvm")
+        fadd2 = tvm.tir.build(mod2, "llvm")
         path1 = temp.relpath("myadd1.o")
         path2 = temp.relpath("myadd2.o")
         path_dso = temp.relpath("mylib.so")
@@ -206,9 +189,9 @@ def test_combine_module_llvm():
             print("Skip because llvm is not enabled")
             return
         temp = utils.tempdir()
-        runtime = Runtime("cpp", {"system-lib": True})
-        fadd1 = tvm.build(s, [A, B], "llvm", runtime=runtime, name="myadd1")
-        fadd2 = tvm.build(s, [A, B], "llvm", runtime=runtime, name="myadd2")
+        print("Running popen check")
+        fadd1 = tvm.tir.build(mod1.with_attr("system_lib_prefix", ""), "llvm")
+        fadd2 = tvm.tir.build(mod2.with_attr("system_lib_prefix", ""), "llvm")
         path1 = temp.relpath("myadd1.o")
         path2 = temp.relpath("myadd2.o")
         path_dso = temp.relpath("mylib.so")
@@ -243,5 +226,3 @@ def test_combine_module_llvm():
 
 if __name__ == "__main__":
     test_combine_module_llvm()
-    test_device_module_dump()
-    test_dso_module_load()
