@@ -147,7 +147,7 @@ def test_tir_too_large_literal_f64():
     def imm_overflow_fp64() -> T.float64:
         T.evaluate(T.ret(T.float64(1.7976e309), dtype="float64"))
 
-    f = tvm.build(imm_overflow_fp64, target="llvm")
+    f = tvm.compile(imm_overflow_fp64, target="llvm")
     assert math.isinf(f())
 
 
@@ -270,7 +270,7 @@ def test_tir_floatimm_const_fold():
         z[()] = x / y
 
     def __wrap_build(f):
-        lib = tvm.build(f, target="llvm")
+        lib = tvm.compile(f, target="llvm")
         z = tvm.nd.array(np.zeros([]).astype("float32"))
 
         def _func(x, y):
@@ -331,11 +331,11 @@ def test_tir_int8_const_fold():
     def imm_floordiv(x: T.int8, y: T.int8) -> T.int8:
         T.evaluate(T.ret(T.floordiv(x, y), dtype="int8"))
 
-    fmul = tvm.build(imm_multiply, target="llvm")
-    fadd = tvm.build(imm_add, target="llvm")
-    fsub = tvm.build(imm_sub, target="llvm")
-    ffloordiv = tvm.build(imm_floordiv, target="llvm")
-    ftruncdiv = tvm.build(imm_truncdiv, target="llvm")
+    fmul = tvm.compile(imm_multiply, target="llvm")
+    fadd = tvm.compile(imm_add, target="llvm")
+    fsub = tvm.compile(imm_sub, target="llvm")
+    ffloordiv = tvm.compile(imm_floordiv, target="llvm")
+    ftruncdiv = tvm.compile(imm_truncdiv, target="llvm")
 
     # overflow
     check_tir_const_fold("int8", lambda x, y: x + y, fadd, 127, 1, -128)
@@ -387,11 +387,11 @@ def test_tir_uint8_const_fold():
     def imm_floordiv(x: T.uint8, y: T.uint8) -> T.uint8:
         T.evaluate(T.ret(T.floordiv(x, y), dtype="uint8"))
 
-    fmul = tvm.build(imm_multiply, target="llvm")
-    fadd = tvm.build(imm_add, target="llvm")
-    fsub = tvm.build(imm_sub, target="llvm")
-    ffloordiv = tvm.build(imm_floordiv, target="llvm")
-    ftruncdiv = tvm.build(imm_truncdiv, target="llvm")
+    fmul = tvm.compile(imm_multiply, target="llvm")
+    fadd = tvm.compile(imm_add, target="llvm")
+    fsub = tvm.compile(imm_sub, target="llvm")
+    ffloordiv = tvm.compile(imm_floordiv, target="llvm")
+    ftruncdiv = tvm.compile(imm_truncdiv, target="llvm")
 
     # overflow
     check_tir_const_fold("uint8", lambda x, y: x + y, fadd, 255, 1, 0)
@@ -454,13 +454,13 @@ def test_tir_int32_const_fold():
     def imm_floormod(x: T.int32, y: T.int32) -> T.int32:
         T.evaluate(T.ret(T.floormod(x, y), dtype="int32"))
 
-    fmul = tvm.build(imm_multiply, target="llvm")
-    fadd = tvm.build(imm_add, target="llvm")
-    fsub = tvm.build(imm_sub, target="llvm")
-    ffloordiv = tvm.build(imm_floordiv, target="llvm")
-    ffloormod = tvm.build(imm_floormod, target="llvm")
-    ftruncdiv = tvm.build(imm_truncdiv, target="llvm")
-    ftruncmod = tvm.build(imm_truncmod, target="llvm")
+    fmul = tvm.compile(imm_multiply, target="llvm")
+    fadd = tvm.compile(imm_add, target="llvm")
+    fsub = tvm.compile(imm_sub, target="llvm")
+    ffloordiv = tvm.compile(imm_floordiv, target="llvm")
+    ffloormod = tvm.compile(imm_floormod, target="llvm")
+    ftruncdiv = tvm.compile(imm_truncdiv, target="llvm")
+    ftruncmod = tvm.compile(imm_truncmod, target="llvm")
 
     # i32 overflow is not specified, only check for range
     assert -(2**31) <= int(tir.const(2**31 - 1, "int32") + tir.const(1, "int32")) < 2**31
@@ -534,11 +534,11 @@ def test_tir_uint32_const_fold():
     def imm_floordiv(x: T.uint32, y: T.uint32) -> T.uint32:
         T.evaluate(T.ret(T.floordiv(x, y), dtype="uint32"))
 
-    fmul = tvm.build(imm_multiply, target="llvm")
-    fadd = tvm.build(imm_add, target="llvm")
-    fsub = tvm.build(imm_sub, target="llvm")
-    ffloordiv = tvm.build(imm_floordiv, target="llvm")
-    ftruncdiv = tvm.build(imm_truncdiv, target="llvm")
+    fmul = tvm.compile(imm_multiply, target="llvm")
+    fadd = tvm.compile(imm_add, target="llvm")
+    fsub = tvm.compile(imm_sub, target="llvm")
+    ffloordiv = tvm.compile(imm_floordiv, target="llvm")
+    ftruncdiv = tvm.compile(imm_truncdiv, target="llvm")
 
     # u32 overflow is not specified, only check for range
     assert 0 <= int(tir.const(2**32 - 1, "uint32") + tir.const(1, "uint32")) < 2**32
