@@ -41,8 +41,8 @@ def check_rolling_buffer(
         x = tvm.nd.array(np.random.uniform(0, 64, in_shape).astype(in_buffer.dtype))
         y0 = tvm.nd.array(np.zeros(out_shape).astype(out_buffer.dtype))
         y1 = tvm.nd.array(np.zeros(out_shape).astype(out_buffer.dtype))
-        f_origin = tvm.build(origin)
-        f_scheduled = tvm.build(scheduled)
+        f_origin = tvm.compile(origin)
+        f_scheduled = tvm.compile(scheduled)
         f_origin(x, y0)
         f_scheduled(x, y1)
         tvm.testing.assert_allclose(y0.numpy(), y1.numpy())
