@@ -142,7 +142,7 @@ def test_inject_async_copy():
             continue
 
         with tvm.transform.PassContext(config={"tir.use_async_copy": 1}):
-            mod = tvm.build(tvm.IRModule.from_expr(f), target="cuda")
+            mod = tvm.compile(tvm.IRModule.from_expr(f), target="cuda")
 
         A_np = np.random.rand(32, 128).astype(dtype)
         B_np = np.zeros((32, 128)).astype(dtype)
@@ -170,7 +170,7 @@ def test_inject_async_copy_shared_dyn():
         return
 
     with tvm.transform.PassContext(config={"tir.use_async_copy": 1}):
-        mod = tvm.build(tvm.IRModule.from_expr(f), target="cuda")
+        mod = tvm.compile(tvm.IRModule.from_expr(f), target="cuda")
 
     A_np = np.random.rand(32, 128).astype("float16")
     B_np = np.random.rand(32, 128).astype("float16")
@@ -228,7 +228,7 @@ def test_inject_async_copy_barrier():
 
     if tvm.testing.is_ampere_or_newer():
         with tvm.transform.PassContext(config={"tir.use_async_copy": 1}):
-            mod = tvm.build(tvm.IRModule.from_expr(f), target="cuda")
+            mod = tvm.compile(tvm.IRModule.from_expr(f), target="cuda")
 
         A_np = np.random.rand(32, 128).astype(dtype)
         B_np = np.zeros((32, 128)).astype(dtype)
@@ -477,7 +477,7 @@ def test_cp_async_in_if_then_else(postproc_if_missing_async_support):
 
     mod = tvm.IRModule.from_expr(simple_compute)
     with tvm.transform.PassContext(config={"tir.use_async_copy": 1}):
-        tvm.build(mod, target="cuda")
+        tvm.compile(mod, target="cuda")
     generated_code = postproc_if_missing_async_support()
     assert generated_code == expected_cuda_script
 
@@ -938,7 +938,7 @@ def test_vectorize_cp_async_in_if_then_else(postproc_if_missing_async_support):
 
     mod = tvm.IRModule.from_expr(complex_compute)
     with tvm.transform.PassContext(config={"tir.use_async_copy": 1}):
-        tvm.build(mod, target="cuda")
+        tvm.compile(mod, target="cuda")
     generated_code = postproc_if_missing_async_support()
     # generated_code must contain "  setp.ne.b32 p, %0, 0;"
     assert "setp.ne.b32" in generated_code
