@@ -116,8 +116,6 @@ def test_tir_macro_decorator_signature():
     def func1():
         T.evaluate(0)
 
-    assert func1.hygienic
-
     @T.prim_func(private=True)
     def use1():
         func1()
@@ -129,8 +127,6 @@ def test_tir_macro_decorator_signature():
     def func2():
         T.evaluate(0)
 
-    assert func2.hygienic
-
     @T.prim_func(private=True)
     def use2():
         func2()
@@ -212,6 +208,44 @@ def test_tir_macro_non_hygienic():
     tvm.ir.assert_structural_equal(use_non_hygienic, expected_non_hygienic)
 
 
+def test_tir_macro_in_class():
+    class Object:
+        def __init__(self, x: T.Buffer):
+            self.local_x = T.alloc_buffer(x.shape, x.dtype)
+
+        @T.macro
+        def load(self, x: T.Buffer):
+            N, M = T.meta_var(self.local_x.shape)
+            for i, j in T.grid(N, M):
+                with T.block("update"):
+                    vi, vj = T.axis.remap("SS", [i, j])
+                    self.local_x[vi, vj] = x[vi, vj]
+
+    @T.prim_func(private=True)
+    def func_w_macro(a: T.handle):
+        A = T.match_buffer(a, [128, 128])
+        o1 = T.meta_var(Object(A))
+        o1.load(A)
+        o2 = T.meta_var(Object(A))
+        o2.load(o1.local_x)
+
+    @T.prim_func(private=True)
+    def func_no_macro(a: T.handle):
+        A = T.match_buffer(a, [128, 128])
+        local_a = T.alloc_buffer([128, 128])
+        for i, j in T.grid(128, 128):
+            with T.block("update"):
+                vi, vj = T.axis.remap("SS", [i, j])
+                local_a[vi, vj] = A[vi, vj]
+        local_b = T.alloc_buffer([128, 128])
+        for i, j in T.grid(128, 128):
+            with T.block("update"):
+                vi, vj = T.axis.remap("SS", [i, j])
+                local_b[vi, vj] = local_a[vi, vj]
+
+    tvm.ir.assert_structural_equal(func_no_macro, func_w_macro)
+
+
 def test_tir_starred_expression():
     dims = (128, 128)
 
